/**
 * Oracle API Access Control
 * This service is used to restrict the control plane service apis; so that everybody won't be
able to access those apis.
There are two main resouces defined as a part of this service
1. PrivilegedApiControl: This is created by the customer which defines which service apis are
   controlled and who can access it.
2. PrivilegedApiRequest: This is a request object again created by the customer operators who           seek access to those privileged apis. After a request is obtained based on the                       PrivilegedAccessControl for which the api belongs to, either it can be approved so that the          requested person can execute the service apis or it will wait for the customer to approve it.

 * OpenAPI spec version: 20241130
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * An asynchronous work request. Work requests help you monitor long-running operations. When you start a long-running operation,
 * the service creates a work request. A work request is an activity log that lets you track each step in the operation's
 * progress. Each work request has an OCID that lets you interact with it programmatically and use it for automation.
 *
 */
export interface WorkRequest {
    /**
     * The asynchronous operation tracked by this work request.
     */
    "operationType": model.OperationType;
    /**
     * The status of the work request.
     */
    "status": model.OperationStatus;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the work request.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the work request.
     *
     */
    "compartmentId": string;
    /**
     * The resources that are affected by the work request.
     */
    "resources": Array<model.WorkRequestResource>;
    /**
     * Shows the progress of the operation tracked by the work request, as a percentage of the total work
     * that must be performed.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete": number;
    /**
     * The date and time the work request was created, in the format defined by
     * [RFC 3339](https://tools.ietf.org/html/rfc3339).
     *
     */
    "timeAccepted": Date;
    /**
     * The date and time the work request was started, in the format defined by
     * [RFC 3339](https://tools.ietf.org/html/rfc3339).
     *
     */
    "timeStarted"?: Date;
    /**
     * The date and time the work request was finished, in the format defined by
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
     *
     */
    "timeFinished"?: Date;
    /**
     * The date and time the work request was updated, in the format defined by
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
     *
     */
    "timeUpdated"?: Date;
}
export declare namespace WorkRequest {
    function getJsonObj(obj: WorkRequest): object;
    function getDeserializedJsonObj(obj: WorkRequest): object;
}
