/**
 * OCI Control Center Capacity Management API
 * OCI Control Center (OCC) Capacity Management enables you to manage capacity requests in realms where OCI Control Center Capacity Management is available. For more information, see [OCI Control Center](https://docs.oracle.com/iaas/Content/control-center/home.htm).
 * OpenAPI spec version: 20231107
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { CapacityManagementWaiter } from "./capacitymanagement-waiter";
import { DemandSignalWaiter } from "./demandsignal-waiter";
import { InternalDemandSignalWaiter } from "./internaldemandsignal-waiter";
declare const Breaker: any;
export declare enum CapacityManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class CapacityManagementClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": CapacityManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new CapacityManagementWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): CapacityManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): CapacityManagementWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Create availability catalog
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccAvailabilityCatalogRequest
     * @return CreateOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateOccAvailabilityCatalog.ts.html |here} to see how to use CreateOccAvailabilityCatalog API.
     */
    createOccAvailabilityCatalog(createOccAvailabilityCatalogRequest: requests.CreateOccAvailabilityCatalogRequest): Promise<responses.CreateOccAvailabilityCatalogResponse>;
    /**
     * Create Capacity Request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccCapacityRequestRequest
     * @return CreateOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateOccCapacityRequest.ts.html |here} to see how to use CreateOccCapacityRequest API.
     */
    createOccCapacityRequest(createOccCapacityRequestRequest: requests.CreateOccCapacityRequestRequest): Promise<responses.CreateOccCapacityRequestResponse>;
    /**
     * Create customer.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccCustomerRequest
     * @return CreateOccCustomerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateOccCustomer.ts.html |here} to see how to use CreateOccCustomer API.
     */
    createOccCustomer(createOccCustomerRequest: requests.CreateOccCustomerRequest): Promise<responses.CreateOccCustomerResponse>;
    /**
     * Create customer group.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccCustomerGroupRequest
     * @return CreateOccCustomerGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateOccCustomerGroup.ts.html |here} to see how to use CreateOccCustomerGroup API.
     */
    createOccCustomerGroup(createOccCustomerGroupRequest: requests.CreateOccCustomerGroupRequest): Promise<responses.CreateOccCustomerGroupResponse>;
    /**
     * Deletes the availability catalog resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccAvailabilityCatalogRequest
     * @return DeleteOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteOccAvailabilityCatalog.ts.html |here} to see how to use DeleteOccAvailabilityCatalog API.
     */
    deleteOccAvailabilityCatalog(deleteOccAvailabilityCatalogRequest: requests.DeleteOccAvailabilityCatalogRequest): Promise<responses.DeleteOccAvailabilityCatalogResponse>;
    /**
     * Deletes the capacity request resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccCapacityRequestRequest
     * @return DeleteOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteOccCapacityRequest.ts.html |here} to see how to use DeleteOccCapacityRequest API.
     */
    deleteOccCapacityRequest(deleteOccCapacityRequestRequest: requests.DeleteOccCapacityRequestRequest): Promise<responses.DeleteOccCapacityRequestResponse>;
    /**
     * Deletes the customer resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccCustomerRequest
     * @return DeleteOccCustomerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteOccCustomer.ts.html |here} to see how to use DeleteOccCustomer API.
     */
    deleteOccCustomer(deleteOccCustomerRequest: requests.DeleteOccCustomerRequest): Promise<responses.DeleteOccCustomerResponse>;
    /**
     * Deletes the customer group resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccCustomerGroupRequest
     * @return DeleteOccCustomerGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteOccCustomerGroup.ts.html |here} to see how to use DeleteOccCustomerGroup API.
     */
    deleteOccCustomerGroup(deleteOccCustomerGroupRequest: requests.DeleteOccCustomerGroupRequest): Promise<responses.DeleteOccCustomerGroupResponse>;
    /**
     * Get details about availability catalog.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccAvailabilityCatalogRequest
     * @return GetOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetOccAvailabilityCatalog.ts.html |here} to see how to use GetOccAvailabilityCatalog API.
     */
    getOccAvailabilityCatalog(getOccAvailabilityCatalogRequest: requests.GetOccAvailabilityCatalogRequest): Promise<responses.GetOccAvailabilityCatalogResponse>;
    /**
     * Returns the binary contents of the availability catalog. Can be saved as a csv file.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccAvailabilityCatalogContentRequest
     * @return GetOccAvailabilityCatalogContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetOccAvailabilityCatalogContent.ts.html |here} to see how to use GetOccAvailabilityCatalogContent API.
     */
    getOccAvailabilityCatalogContent(getOccAvailabilityCatalogContentRequest: requests.GetOccAvailabilityCatalogContentRequest): Promise<responses.GetOccAvailabilityCatalogContentResponse>;
    /**
     * Get details about the capacity request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccCapacityRequestRequest
     * @return GetOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetOccCapacityRequest.ts.html |here} to see how to use GetOccCapacityRequest API.
     */
    getOccCapacityRequest(getOccCapacityRequestRequest: requests.GetOccCapacityRequestRequest): Promise<responses.GetOccCapacityRequestResponse>;
    /**
     * Gets information about the specified customer group.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccCustomerGroupRequest
     * @return GetOccCustomerGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetOccCustomerGroup.ts.html |here} to see how to use GetOccCustomerGroup API.
     */
    getOccCustomerGroup(getOccCustomerGroupRequest: requests.GetOccCustomerGroupRequest): Promise<responses.GetOccCustomerGroupResponse>;
    /**
     * Lists an overview of all resources in that namespace in a given time interval.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalNamespaceOccOverviewsRequest
     * @return ListInternalNamespaceOccOverviewsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalNamespaceOccOverviews.ts.html |here} to see how to use ListInternalNamespaceOccOverviews API.
     */
    listInternalNamespaceOccOverviews(listInternalNamespaceOccOverviewsRequest: requests.ListInternalNamespaceOccOverviewsRequest): Promise<responses.ListInternalNamespaceOccOverviewsResponse>;
    /**
     * List details about a given occHandoverResourceBlock.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccHandoverResourceBlockDetailsRequest
     * @return ListInternalOccHandoverResourceBlockDetailsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccHandoverResourceBlockDetails.ts.html |here} to see how to use ListInternalOccHandoverResourceBlockDetails API.
     */
    listInternalOccHandoverResourceBlockDetails(listInternalOccHandoverResourceBlockDetailsRequest: requests.ListInternalOccHandoverResourceBlockDetailsRequest): Promise<responses.ListInternalOccHandoverResourceBlockDetailsResponse>;
    /**
     * List Occ Handover Resource blocks.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccHandoverResourceBlocksRequest
     * @return ListInternalOccHandoverResourceBlocksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccHandoverResourceBlocks.ts.html |here} to see how to use ListInternalOccHandoverResourceBlocks API.
     */
    listInternalOccHandoverResourceBlocks(listInternalOccHandoverResourceBlocksRequest: requests.ListInternalOccHandoverResourceBlocksRequest): Promise<responses.ListInternalOccHandoverResourceBlocksResponse>;
    /**
     * Lists availabilities for a particular availability catalog.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccAvailabilitiesRequest
     * @return ListOccAvailabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccAvailabilities.ts.html |here} to see how to use ListOccAvailabilities API.
     */
    listOccAvailabilities(listOccAvailabilitiesRequest: requests.ListOccAvailabilitiesRequest): Promise<responses.ListOccAvailabilitiesResponse>;
    /**
     * Lists all availability catalogs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccAvailabilityCatalogsRequest
     * @return ListOccAvailabilityCatalogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccAvailabilityCatalogs.ts.html |here} to see how to use ListOccAvailabilityCatalogs API.
     */
    listOccAvailabilityCatalogs(listOccAvailabilityCatalogsRequest: requests.ListOccAvailabilityCatalogsRequest): Promise<responses.ListOccAvailabilityCatalogsResponse>;
    /**
     * An internal api to list availability catalogs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccAvailabilityCatalogsInternalRequest
     * @return ListOccAvailabilityCatalogsInternalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccAvailabilityCatalogsInternal.ts.html |here} to see how to use ListOccAvailabilityCatalogsInternal API.
     */
    listOccAvailabilityCatalogsInternal(listOccAvailabilityCatalogsInternalRequest: requests.ListOccAvailabilityCatalogsInternalRequest): Promise<responses.ListOccAvailabilityCatalogsInternalResponse>;
    /**
     * Lists all capacity requests.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccCapacityRequestsRequest
     * @return ListOccCapacityRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccCapacityRequests.ts.html |here} to see how to use ListOccCapacityRequests API.
     */
    listOccCapacityRequests(listOccCapacityRequestsRequest: requests.ListOccCapacityRequestsRequest): Promise<responses.ListOccCapacityRequestsResponse>;
    /**
     * An internal api to list all capacity requests.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccCapacityRequestsInternalRequest
     * @return ListOccCapacityRequestsInternalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccCapacityRequestsInternal.ts.html |here} to see how to use ListOccCapacityRequestsInternal API.
     */
    listOccCapacityRequestsInternal(listOccCapacityRequestsInternalRequest: requests.ListOccCapacityRequestsInternalRequest): Promise<responses.ListOccCapacityRequestsInternalResponse>;
    /**
     * Lists all the customer groups.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccCustomerGroupsRequest
     * @return ListOccCustomerGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccCustomerGroups.ts.html |here} to see how to use ListOccCustomerGroups API.
     */
    listOccCustomerGroups(listOccCustomerGroupsRequest: requests.ListOccCustomerGroupsRequest): Promise<responses.ListOccCustomerGroupsResponse>;
    /**
     * List details about a given occHandoverResourceBlock.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccHandoverResourceBlockDetailsRequest
     * @return ListOccHandoverResourceBlockDetailsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccHandoverResourceBlockDetails.ts.html |here} to see how to use ListOccHandoverResourceBlockDetails API.
     */
    listOccHandoverResourceBlockDetails(listOccHandoverResourceBlockDetailsRequest: requests.ListOccHandoverResourceBlockDetailsRequest): Promise<responses.ListOccHandoverResourceBlockDetailsResponse>;
    /**
     * List Occ Handover Resource blocks.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccHandoverResourceBlocksRequest
     * @return ListOccHandoverResourceBlocksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccHandoverResourceBlocks.ts.html |here} to see how to use ListOccHandoverResourceBlocks API.
     */
    listOccHandoverResourceBlocks(listOccHandoverResourceBlocksRequest: requests.ListOccHandoverResourceBlocksRequest): Promise<responses.ListOccHandoverResourceBlocksResponse>;
    /**
     * Lists an overview of all resources in that namespace in a given time interval.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccOverviewsRequest
     * @return ListOccOverviewsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccOverviews.ts.html |here} to see how to use ListOccOverviews API.
     */
    listOccOverviews(listOccOverviewsRequest: requests.ListOccOverviewsRequest): Promise<responses.ListOccOverviewsResponse>;
    /**
     * Updates the OccCapacityRequest by evaluating a sequence of instructions.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PatchInternalOccCapacityRequestRequest
     * @return PatchInternalOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/PatchInternalOccCapacityRequest.ts.html |here} to see how to use PatchInternalOccCapacityRequest API.
     */
    patchInternalOccCapacityRequest(patchInternalOccCapacityRequestRequest: requests.PatchInternalOccCapacityRequestRequest): Promise<responses.PatchInternalOccCapacityRequestResponse>;
    /**
     * Updates the OccCapacityRequest by evaluating a sequence of instructions.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PatchOccCapacityRequestRequest
     * @return PatchOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/PatchOccCapacityRequest.ts.html |here} to see how to use PatchOccCapacityRequest API.
     */
    patchOccCapacityRequest(patchOccCapacityRequestRequest: requests.PatchOccCapacityRequestRequest): Promise<responses.PatchOccCapacityRequestResponse>;
    /**
     * Publishes the version of availability catalog specified by the operator. This makes that catalog version visible to customers.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PublishOccAvailabilityCatalogRequest
     * @return PublishOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/PublishOccAvailabilityCatalog.ts.html |here} to see how to use PublishOccAvailabilityCatalog API.
     */
    publishOccAvailabilityCatalog(publishOccAvailabilityCatalogRequest: requests.PublishOccAvailabilityCatalogRequest): Promise<responses.PublishOccAvailabilityCatalogResponse>;
    /**
     * The internal api to update the capacity request. This api will be used by operators for updating the capacity request to either completed, resubmitted or rejected.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateInternalOccCapacityRequestRequest
     * @return UpdateInternalOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateInternalOccCapacityRequest.ts.html |here} to see how to use UpdateInternalOccCapacityRequest API.
     */
    updateInternalOccCapacityRequest(updateInternalOccCapacityRequestRequest: requests.UpdateInternalOccCapacityRequestRequest): Promise<responses.UpdateInternalOccCapacityRequestResponse>;
    /**
     * The request to update the availability catalog. Currently only freeform tags can be updated via this api.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccAvailabilityCatalogRequest
     * @return UpdateOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateOccAvailabilityCatalog.ts.html |here} to see how to use UpdateOccAvailabilityCatalog API.
     */
    updateOccAvailabilityCatalog(updateOccAvailabilityCatalogRequest: requests.UpdateOccAvailabilityCatalogRequest): Promise<responses.UpdateOccAvailabilityCatalogResponse>;
    /**
     * The request to update the capacity request. The user can perform actions like closing a partially completed request so that it doesn't go ahead for full completion.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccCapacityRequestRequest
     * @return UpdateOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateOccCapacityRequest.ts.html |here} to see how to use UpdateOccCapacityRequest API.
     */
    updateOccCapacityRequest(updateOccCapacityRequestRequest: requests.UpdateOccCapacityRequestRequest): Promise<responses.UpdateOccCapacityRequestResponse>;
    /**
     * The request to update the customer.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccCustomerRequest
     * @return UpdateOccCustomerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateOccCustomer.ts.html |here} to see how to use UpdateOccCustomer API.
     */
    updateOccCustomer(updateOccCustomerRequest: requests.UpdateOccCustomerRequest): Promise<responses.UpdateOccCustomerResponse>;
    /**
     * The request to update the customer group.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccCustomerGroupRequest
     * @return UpdateOccCustomerGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateOccCustomerGroup.ts.html |here} to see how to use UpdateOccCustomerGroup API.
     */
    updateOccCustomerGroup(updateOccCustomerGroupRequest: requests.UpdateOccCustomerGroupRequest): Promise<responses.UpdateOccCustomerGroupResponse>;
}
export declare enum DemandSignalApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DemandSignalClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DemandSignalWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DemandSignalWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DemandSignalWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DemandSignalWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * This API will help in bulk creation of demand signal items. This API is atomic i.e either all the demand signal item resources will be created or none will be created.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkCreateOccmDemandSignalItemRequest
     * @return BulkCreateOccmDemandSignalItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/BulkCreateOccmDemandSignalItem.ts.html |here} to see how to use BulkCreateOccmDemandSignalItem API.
     */
    bulkCreateOccmDemandSignalItem(bulkCreateOccmDemandSignalItemRequest: requests.BulkCreateOccmDemandSignalItemRequest): Promise<responses.BulkCreateOccmDemandSignalItemResponse>;
    /**
     * This is a post API to create occm demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccmDemandSignalRequest
     * @return CreateOccmDemandSignalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateOccmDemandSignal.ts.html |here} to see how to use CreateOccmDemandSignal API.
     */
    createOccmDemandSignal(createOccmDemandSignalRequest: requests.CreateOccmDemandSignalRequest): Promise<responses.CreateOccmDemandSignalResponse>;
    /**
     * This API will create a demand signal item representing a resource request. This needs to be grouped under a demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccmDemandSignalItemRequest
     * @return CreateOccmDemandSignalItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateOccmDemandSignalItem.ts.html |here} to see how to use CreateOccmDemandSignalItem API.
     */
    createOccmDemandSignalItem(createOccmDemandSignalItemRequest: requests.CreateOccmDemandSignalItemRequest): Promise<responses.CreateOccmDemandSignalItemResponse>;
    /**
     * This is a DELETE API which deletes a demand signal with the provided demand signal ocid.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccmDemandSignalRequest
     * @return DeleteOccmDemandSignalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteOccmDemandSignal.ts.html |here} to see how to use DeleteOccmDemandSignal API.
     */
    deleteOccmDemandSignal(deleteOccmDemandSignalRequest: requests.DeleteOccmDemandSignalRequest): Promise<responses.DeleteOccmDemandSignalResponse>;
    /**
     * This is a DELETE API which deletes a demand signal item with the provided demand signal item ocid.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccmDemandSignalItemRequest
     * @return DeleteOccmDemandSignalItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteOccmDemandSignalItem.ts.html |here} to see how to use DeleteOccmDemandSignalItem API.
     */
    deleteOccmDemandSignalItem(deleteOccmDemandSignalItemRequest: requests.DeleteOccmDemandSignalItemRequest): Promise<responses.DeleteOccmDemandSignalItemResponse>;
    /**
     * This is a GET API which gets the detailed information about a specific demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccmDemandSignalRequest
     * @return GetOccmDemandSignalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetOccmDemandSignal.ts.html |here} to see how to use GetOccmDemandSignal API.
     */
    getOccmDemandSignal(getOccmDemandSignalRequest: requests.GetOccmDemandSignalRequest): Promise<responses.GetOccmDemandSignalResponse>;
    /**
     * This is a GET API to get the details of a demand signal item resource representing the details of the resource demanded by you.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccmDemandSignalItemRequest
     * @return GetOccmDemandSignalItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetOccmDemandSignalItem.ts.html |here} to see how to use GetOccmDemandSignalItem API.
     */
    getOccmDemandSignalItem(getOccmDemandSignalItemRequest: requests.GetOccmDemandSignalItemRequest): Promise<responses.GetOccmDemandSignalItemResponse>;
    /**
     * This API will list all the  resources across all demand signal catalogs for a given namespace and customer group containing the caller compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccmDemandSignalCatalogResourcesRequest
     * @return ListOccmDemandSignalCatalogResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccmDemandSignalCatalogResources.ts.html |here} to see how to use ListOccmDemandSignalCatalogResources API.
     */
    listOccmDemandSignalCatalogResources(listOccmDemandSignalCatalogResourcesRequest: requests.ListOccmDemandSignalCatalogResourcesRequest): Promise<responses.ListOccmDemandSignalCatalogResourcesResponse>;
    /**
     * This GET call is used to list all demand signals delivery resources within the compartment passed as a query param.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccmDemandSignalDeliveriesRequest
     * @return ListOccmDemandSignalDeliveriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccmDemandSignalDeliveries.ts.html |here} to see how to use ListOccmDemandSignalDeliveries API.
     */
    listOccmDemandSignalDeliveries(listOccmDemandSignalDeliveriesRequest: requests.ListOccmDemandSignalDeliveriesRequest): Promise<responses.ListOccmDemandSignalDeliveriesResponse>;
    /**
     * This API will list the detailed information about the resources demanded as part of the demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccmDemandSignalItemsRequest
     * @return ListOccmDemandSignalItemsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccmDemandSignalItems.ts.html |here} to see how to use ListOccmDemandSignalItems API.
     */
    listOccmDemandSignalItems(listOccmDemandSignalItemsRequest: requests.ListOccmDemandSignalItemsRequest): Promise<responses.ListOccmDemandSignalItemsResponse>;
    /**
     * This GET call is used to list all demand signals within the compartment passed as a query parameter.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccmDemandSignalsRequest
     * @return ListOccmDemandSignalsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListOccmDemandSignals.ts.html |here} to see how to use ListOccmDemandSignals API.
     */
    listOccmDemandSignals(listOccmDemandSignalsRequest: requests.ListOccmDemandSignalsRequest): Promise<responses.ListOccmDemandSignalsResponse>;
    /**
     * This is a PUT API which shall be used to update the metadata of the demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccmDemandSignalRequest
     * @return UpdateOccmDemandSignalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateOccmDemandSignal.ts.html |here} to see how to use UpdateOccmDemandSignal API.
     */
    updateOccmDemandSignal(updateOccmDemandSignalRequest: requests.UpdateOccmDemandSignalRequest): Promise<responses.UpdateOccmDemandSignalResponse>;
    /**
     * This is a PUT API which can be used to update the demand signal item resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccmDemandSignalItemRequest
     * @return UpdateOccmDemandSignalItemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateOccmDemandSignalItem.ts.html |here} to see how to use UpdateOccmDemandSignalItem API.
     */
    updateOccmDemandSignalItem(updateOccmDemandSignalItemRequest: requests.UpdateOccmDemandSignalItemRequest): Promise<responses.UpdateOccmDemandSignalItemResponse>;
}
export declare enum InternalDemandSignalApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class InternalDemandSignalClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": InternalDemandSignalWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new InternalDemandSignalWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): InternalDemandSignalWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): InternalDemandSignalWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * This is a post API which is used to create a demand signal delivery resource.
     * operationId: CreateInternalOccmDemandSignalDelivery
     * summary: A post call to create a demand signal delivery.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateInternalOccmDemandSignalDeliveryRequest
     * @return CreateInternalOccmDemandSignalDeliveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/CreateInternalOccmDemandSignalDelivery.ts.html |here} to see how to use CreateInternalOccmDemandSignalDelivery API.
     */
    createInternalOccmDemandSignalDelivery(createInternalOccmDemandSignalDeliveryRequest: requests.CreateInternalOccmDemandSignalDeliveryRequest): Promise<responses.CreateInternalOccmDemandSignalDeliveryResponse>;
    /**
     * This is an internal DELETE API which is used to delete a demand signal delivery resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteInternalOccmDemandSignalDeliveryRequest
     * @return DeleteInternalOccmDemandSignalDeliveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/DeleteInternalOccmDemandSignalDelivery.ts.html |here} to see how to use DeleteInternalOccmDemandSignalDelivery API.
     */
    deleteInternalOccmDemandSignalDelivery(deleteInternalOccmDemandSignalDeliveryRequest: requests.DeleteInternalOccmDemandSignalDeliveryRequest): Promise<responses.DeleteInternalOccmDemandSignalDeliveryResponse>;
    /**
     * This is an internal GET API which gets the detailed information about a specific demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetInternalOccmDemandSignalRequest
     * @return GetInternalOccmDemandSignalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetInternalOccmDemandSignal.ts.html |here} to see how to use GetInternalOccmDemandSignal API.
     */
    getInternalOccmDemandSignal(getInternalOccmDemandSignalRequest: requests.GetInternalOccmDemandSignalRequest): Promise<responses.GetInternalOccmDemandSignalResponse>;
    /**
     * This API helps in getting the details about a specific occm demand signal catalog.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetInternalOccmDemandSignalCatalogRequest
     * @return GetInternalOccmDemandSignalCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetInternalOccmDemandSignalCatalog.ts.html |here} to see how to use GetInternalOccmDemandSignalCatalog API.
     */
    getInternalOccmDemandSignalCatalog(getInternalOccmDemandSignalCatalogRequest: requests.GetInternalOccmDemandSignalCatalogRequest): Promise<responses.GetInternalOccmDemandSignalCatalogResponse>;
    /**
     * This is an internal GET API to get the details of a demand signal delivery resource corresponding to a demand signal item.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetInternalOccmDemandSignalDeliveryRequest
     * @return GetInternalOccmDemandSignalDeliveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/GetInternalOccmDemandSignalDelivery.ts.html |here} to see how to use GetInternalOccmDemandSignalDelivery API.
     */
    getInternalOccmDemandSignalDelivery(getInternalOccmDemandSignalDeliveryRequest: requests.GetInternalOccmDemandSignalDeliveryRequest): Promise<responses.GetInternalOccmDemandSignalDeliveryResponse>;
    /**
     * This API will list all the  resources across all demand signal catalogs for a given namespace and customer group.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccmDemandSignalCatalogResourcesRequest
     * @return ListInternalOccmDemandSignalCatalogResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccmDemandSignalCatalogResources.ts.html |here} to see how to use ListInternalOccmDemandSignalCatalogResources API.
     */
    listInternalOccmDemandSignalCatalogResources(listInternalOccmDemandSignalCatalogResourcesRequest: requests.ListInternalOccmDemandSignalCatalogResourcesRequest): Promise<responses.ListInternalOccmDemandSignalCatalogResourcesResponse>;
    /**
     * This API will list demand signal catalogs for a given customer group.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccmDemandSignalCatalogsRequest
     * @return ListInternalOccmDemandSignalCatalogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccmDemandSignalCatalogs.ts.html |here} to see how to use ListInternalOccmDemandSignalCatalogs API.
     */
    listInternalOccmDemandSignalCatalogs(listInternalOccmDemandSignalCatalogsRequest: requests.ListInternalOccmDemandSignalCatalogsRequest): Promise<responses.ListInternalOccmDemandSignalCatalogsResponse>;
    /**
     * This GET call is used to list all demand signal delivery resources within the customer group passed as a query parameter.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccmDemandSignalDeliveriesRequest
     * @return ListInternalOccmDemandSignalDeliveriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccmDemandSignalDeliveries.ts.html |here} to see how to use ListInternalOccmDemandSignalDeliveries API.
     */
    listInternalOccmDemandSignalDeliveries(listInternalOccmDemandSignalDeliveriesRequest: requests.ListInternalOccmDemandSignalDeliveriesRequest): Promise<responses.ListInternalOccmDemandSignalDeliveriesResponse>;
    /**
     * This internal API will list the detailed information about the resources demanded as part of the demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccmDemandSignalItemsRequest
     * @return ListInternalOccmDemandSignalItemsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccmDemandSignalItems.ts.html |here} to see how to use ListInternalOccmDemandSignalItems API.
     */
    listInternalOccmDemandSignalItems(listInternalOccmDemandSignalItemsRequest: requests.ListInternalOccmDemandSignalItemsRequest): Promise<responses.ListInternalOccmDemandSignalItemsResponse>;
    /**
     * This is an internal GET call is used to list all demand signals within the compartment passed as a query parameter.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalOccmDemandSignalsRequest
     * @return ListInternalOccmDemandSignalsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/ListInternalOccmDemandSignals.ts.html |here} to see how to use ListInternalOccmDemandSignals API.
     */
    listInternalOccmDemandSignals(listInternalOccmDemandSignalsRequest: requests.ListInternalOccmDemandSignalsRequest): Promise<responses.ListInternalOccmDemandSignalsResponse>;
    /**
     * This is a internal PUT API which shall be used to update the metadata of the demand signal.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateInternalOccmDemandSignalRequest
     * @return UpdateInternalOccmDemandSignalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateInternalOccmDemandSignal.ts.html |here} to see how to use UpdateInternalOccmDemandSignal API.
     */
    updateInternalOccmDemandSignal(updateInternalOccmDemandSignalRequest: requests.UpdateInternalOccmDemandSignalRequest): Promise<responses.UpdateInternalOccmDemandSignalResponse>;
    /**
     * This is an internal PUT API which is used to update the demand signal delivery resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateInternalOccmDemandSignalDeliveryRequest
     * @return UpdateInternalOccmDemandSignalDeliveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/capacitymanagement/UpdateInternalOccmDemandSignalDelivery.ts.html |here} to see how to use UpdateInternalOccmDemandSignalDelivery API.
     */
    updateInternalOccmDemandSignalDelivery(updateInternalOccmDemandSignalDeliveryRequest: requests.UpdateInternalOccmDemandSignalDeliveryRequest): Promise<responses.UpdateInternalOccmDemandSignalDeliveryResponse>;
}
export {};
