/**
 * OCI Control Center Capacity Management API
 * OCI Control Center (OCC) Capacity Management enables you to manage capacity requests in realms where OCI Control Center Capacity Management is available. For more information, see [OCI Control Center](https://docs.oracle.com/iaas/Content/control-center/home.htm).
 * OpenAPI spec version: 20231107
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * An internal summary model containing information about the details of a demand signal items.
 *
 */
export interface InternalOccmDemandSignalItemSummary {
    /**
     * The OCID of the customer group in which the demand signal is created.
     *
     */
    "occCustomerGroupId": string;
    /**
     * The OCID of the demand signal resource request.
     *
     */
    "id": string;
    /**
     * The OCID of the tenancy from which the demand signal item was created.
     *
     */
    "compartmentId": string;
    /**
     * The OCID of the demand signal under which this item will be grouped.
     *
     */
    "demandSignalId": string;
    /**
     * The name of the OCI service in consideration for demand signal submission. For example: COMPUTE, NETWORK, GPU etc.
     *
     */
    "demandSignalNamespace": model.DemandSignalNamespace;
    /**
     * The OCID of the corresponding demand signal catalog resource.
     *
     */
    "demandSignalCatalogResourceId": string;
    /**
     * The type of request (DEMAND or RETURN) made against a particular demand signal item.
     *
     */
    "requestType": model.OccmDemandSignalItemRequestType;
    /**
     * The name of the OCI resource that you want to request.
     *
     */
    "resourceName": string;
    /**
     * The name of region for which you want to request the OCI resource.
     *
     */
    "region": string;
    /**
     * The name of the availability domain for which you want to request the OCI resource.
     *
     */
    "availabilityDomain"?: string;
    /**
     * The ocid of the tenancy for which you want to request the OCI resource for. This is an optional parameter.
     *
     */
    "targetCompartmentId"?: string;
    /**
     * The quantity of the resource that you want to demand from OCI or return to OCI.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "quantity": number;
    /**
     * the date before which you would ideally like the OCI resource to be delivered to you.
     *
     */
    "timeNeededBefore": Date;
    /**
     * A map of various properties associated with the OCI resource.
     *
     */
    "resourceProperties": {
        [key: string]: string;
    };
    /**
      * This field will serve as notes section for you. You can use this section to convey a message to OCI regarding your resource request.
  * <p>
  NOTE: The previous value gets overwritten with the new one for this once updated.
  *
      */
    "notes"?: string;
    /**
     * The current lifecycle state of the demand signal item.
     *
     */
    "lifecycleState": string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace InternalOccmDemandSignalItemSummary {
    function getJsonObj(obj: InternalOccmDemandSignalItemSummary): object;
    function getDeserializedJsonObj(obj: InternalOccmDemandSignalItemSummary): object;
}
