/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](https://docs.oracle.com/iaas/Content/Network/Concepts/overview.htm),
[Compute](https://docs.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](https://docs.oracle.com/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](https://docs.oracle.com/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The customer facing object includes host details.
 *
 */
export interface ComputeHost {
    /**
      * The availability domain of the compute host.
  * <p>
  Example: {@code Uocm:US-CHICAGO-1-AD-2}
  *
      */
    "availabilityDomain": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the compartment. This should always be the root
     * compartment.
     *
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Customer-unique host
     *
     */
    "id": string;
    /**
      * A fault domain is a grouping of hardware and infrastructure within an availability domain.
  * Each availability domain contains three fault domains. Fault domains let you distribute your
  * instances so that they are not on the same physical hardware within a single availability domain.
  * A hardware failure or Compute hardware maintenance that affects one fault domain does not affect
  * instances in other fault domains.
  * <p>
  This field is the Fault domain of the host
  *
      */
    "faultDomain": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for Customer-unique HPC Island
     *
     */
    "hpcIslandId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Customer-unique host group associated with the Compute Bare Metal Host.
     *
     */
    "computeHostGroupId"?: string;
    /**
     * Configuration state of the Compute Bare Metal Host.
     *
     */
    "configurationState"?: model.ConfigurationState;
    /**
      * The date and time that the compute bare metal host configuration check was updated, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeConfigurationCheck"?: Date;
    "configurationData"?: model.ComputeHostConfigurationData;
    "recycleDetails"?: model.RecycleDetails;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for Customer-unique Network Block
     *
     */
    "networkBlockId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for Customer-unique Local Block
     *
     */
    "localBlockId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for Customer-unique GPU Memory Fabric
     *
     */
    "gpuMemoryFabricId"?: string;
    /**
     * The public [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Virtual Machine or Bare Metal instance
     *
     */
    "instanceId"?: string;
    /**
     * The shape of host
     *
     */
    "shape": string;
    /**
     * The heathy state of the host
     *
     */
    "health": ComputeHost.Health;
    /**
     * Additional data that can be exposed to the customer.  Will include raw fault codes for strategic customers
     *
     */
    "additionalData"?: {
        [key: string]: any;
    };
    /**
     * The lifecycle state of the host
     *
     */
    "lifecycleState": ComputeHost.LifecycleState;
    /**
     * A free-form description detailing why the host is in its current state.
     *
     */
    "lifecycleDetails"?: {
        [key: string]: any;
    };
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Capacity Reserver that is currently on host
     *
     */
    "capacityReservationId"?: string;
    /**
     * A list that contains impacted components related to an unhealthy host. An impacted component will be a
     * free-form structure of key values pairs that will provide more or less details based on data tiering
     *
     */
    "impactedComponentDetails"?: {
        [key: string]: any;
    };
    /**
      * The date and time that the compute host record was created, in the format defined by [RFC3339](https://tools
  * .ietf.org/html/rfc3339).
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
      * The date and time that the compute host record was updated, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeUpdated": Date;
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no
  * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
}
export declare namespace ComputeHost {
    enum Health {
        Healthy = "HEALTHY",
        Unhealthy = "UNHEALTHY",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Available = "AVAILABLE",
        Occupied = "OCCUPIED",
        Provisioning = "PROVISIONING",
        Repair = "REPAIR",
        Unavailable = "UNAVAILABLE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ComputeHost): object;
    function getDeserializedJsonObj(obj: ComputeHost): object;
}
