/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](https://docs.oracle.com/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * An Autonomous Database backup.
 *
 */
export interface AutonomousContainerDatabaseBackup {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Autonomous Database backup.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Autonomous Container Database.
     */
    "autonomousContainerDatabaseId": string;
    /**
     * A user-friendly name for the backup. This name need not be unique.
     */
    "displayName": string;
    /**
     * The user-friendly name for the Autonomous Container Database when the Backup was initiated. This name need not be unique. This field captures the name at the time of backup creation, accounting for possible later updates to the display name.
     */
    "acdDisplayName"?: string;
    /**
     * The type of backup.
     */
    "type": AutonomousContainerDatabaseBackup.Type;
    /**
     * Indicates whether the backup is user-initiated or automatic.
     */
    "isAutomatic": boolean;
    /**
     * The date and time the backup started.
     */
    "timeStarted"?: Date;
    /**
     * The date and time the backup completed.
     */
    "timeEnded"?: Date;
    /**
     * Additional information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * The current state of the backup.
     */
    "lifecycleState": AutonomousContainerDatabaseBackup.LifecycleState;
    /**
     * Retention period, in days, for long-term backups Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "retentionPeriodInDays"?: number;
    /**
     * Whether backup is for remote-region or local region
     */
    "isRemoteBackup"?: boolean;
    /**
     * The infrastructure type this resource belongs to.
     */
    "infrastructureType"?: AutonomousContainerDatabaseBackup.InfrastructureType;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * List of Autonomous Databases that is part of this Autonomous Container Database Backup
     */
    "autonomousDatabases"?: Array<model.AutonomousDatabaseInBackup>;
}
export declare namespace AutonomousContainerDatabaseBackup {
    enum Type {
        Incremental = "INCREMENTAL",
        Full = "FULL"
    }
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED"
    }
    enum InfrastructureType {
        Cloud = "CLOUD",
        CloudAtCustomer = "CLOUD_AT_CUSTOMER"
    }
    function getJsonObj(obj: AutonomousContainerDatabaseBackup): object;
    function getDeserializedJsonObj(obj: AutonomousContainerDatabaseBackup): object;
}
