/**
 * Data Science API
 * Use the Data Science API to organize your data science work, access data and computing resources, and build, train, deploy and manage models and model deployments. For more information, see [Data Science](https://docs.oracle.com/iaas/data-science/using/data-science.htm).

 * OpenAPI spec version: 20190101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { DataScienceWaiter } from "./datascience-waiter";
declare const Breaker: any;
export declare enum DataScienceApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DataScienceClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataScienceWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataScienceWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataScienceWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataScienceWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Activates the model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ActivateModelRequest
     * @return ActivateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ActivateModel.ts.html |here} to see how to use ActivateModel API.
     */
    activateModel(activateModelRequest: requests.ActivateModelRequest): Promise<responses.ActivateModelResponse>;
    /**
     * Activates the model deployment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateModelDeploymentRequest
     * @return ActivateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ActivateModelDeployment.ts.html |here} to see how to use ActivateModelDeployment API.
     */
    activateModelDeployment(activateModelDeploymentRequest: requests.ActivateModelDeploymentRequest): Promise<responses.ActivateModelDeploymentResponse>;
    /**
     * Activates the notebook session.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateNotebookSessionRequest
     * @return ActivateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ActivateNotebookSession.ts.html |here} to see how to use ActivateNotebookSession API.
     */
    activateNotebookSession(activateNotebookSessionRequest: requests.ActivateNotebookSessionRequest): Promise<responses.ActivateNotebookSessionResponse>;
    /**
     * Activate schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ActivateScheduleRequest
     * @return ActivateScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ActivateSchedule.ts.html |here} to see how to use ActivateSchedule API.
     */
    activateSchedule(activateScheduleRequest: requests.ActivateScheduleRequest): Promise<responses.ActivateScheduleResponse>;
    /**
     * Cancels an IN_PROGRESS job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelJobRunRequest
     * @return CancelJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CancelJobRun.ts.html |here} to see how to use CancelJobRun API.
     */
    cancelJobRun(cancelJobRunRequest: requests.CancelJobRunRequest): Promise<responses.CancelJobRunResponse>;
    /**
     * Cancel a PipelineRun.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelPipelineRunRequest
     * @return CancelPipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CancelPipelineRun.ts.html |here} to see how to use CancelPipelineRun API.
     */
    cancelPipelineRun(cancelPipelineRunRequest: requests.CancelPipelineRunRequest): Promise<responses.CancelPipelineRunResponse>;
    /**
     * Cancels a work request that has not started.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves a private endpoint into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDataSciencePrivateEndpointCompartmentRequest
     * @return ChangeDataSciencePrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeDataSciencePrivateEndpointCompartment.ts.html |here} to see how to use ChangeDataSciencePrivateEndpointCompartment API.
     */
    changeDataSciencePrivateEndpointCompartment(changeDataSciencePrivateEndpointCompartmentRequest: requests.ChangeDataSciencePrivateEndpointCompartmentRequest): Promise<responses.ChangeDataSciencePrivateEndpointCompartmentResponse>;
    /**
     * Changes a job's compartment
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeJobCompartmentRequest
     * @return ChangeJobCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeJobCompartment.ts.html |here} to see how to use ChangeJobCompartment API.
     */
    changeJobCompartment(changeJobCompartmentRequest: requests.ChangeJobCompartmentRequest): Promise<responses.ChangeJobCompartmentResponse>;
    /**
     * Changes a job run's compartment
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeJobRunCompartmentRequest
     * @return ChangeJobRunCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeJobRunCompartment.ts.html |here} to see how to use ChangeJobRunCompartment API.
     */
    changeJobRunCompartment(changeJobRunCompartmentRequest: requests.ChangeJobRunCompartmentRequest): Promise<responses.ChangeJobRunCompartmentResponse>;
    /**
     * Moves a MlApplication resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMlApplicationCompartmentRequest
     * @return ChangeMlApplicationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeMlApplicationCompartment.ts.html |here} to see how to use ChangeMlApplicationCompartment API.
     */
    changeMlApplicationCompartment(changeMlApplicationCompartmentRequest: requests.ChangeMlApplicationCompartmentRequest): Promise<responses.ChangeMlApplicationCompartmentResponse>;
    /**
     * Moves a MlApplicationImplementation resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMlApplicationImplementationCompartmentRequest
     * @return ChangeMlApplicationImplementationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeMlApplicationImplementationCompartment.ts.html |here} to see how to use ChangeMlApplicationImplementationCompartment API.
     */
    changeMlApplicationImplementationCompartment(changeMlApplicationImplementationCompartmentRequest: requests.ChangeMlApplicationImplementationCompartmentRequest): Promise<responses.ChangeMlApplicationImplementationCompartmentResponse>;
    /**
     * Moves a MlApplicationInstance resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMlApplicationInstanceCompartmentRequest
     * @return ChangeMlApplicationInstanceCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeMlApplicationInstanceCompartment.ts.html |here} to see how to use ChangeMlApplicationInstanceCompartment API.
     */
    changeMlApplicationInstanceCompartment(changeMlApplicationInstanceCompartmentRequest: requests.ChangeMlApplicationInstanceCompartmentRequest): Promise<responses.ChangeMlApplicationInstanceCompartmentResponse>;
    /**
     * Moves a MlApplicationInstanceView resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMlApplicationInstanceViewCompartmentRequest
     * @return ChangeMlApplicationInstanceViewCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeMlApplicationInstanceViewCompartment.ts.html |here} to see how to use ChangeMlApplicationInstanceViewCompartment API.
     */
    changeMlApplicationInstanceViewCompartment(changeMlApplicationInstanceViewCompartmentRequest: requests.ChangeMlApplicationInstanceViewCompartmentRequest): Promise<responses.ChangeMlApplicationInstanceViewCompartmentResponse>;
    /**
     * Moves a model resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeModelCompartmentRequest
     * @return ChangeModelCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeModelCompartment.ts.html |here} to see how to use ChangeModelCompartment API.
     */
    changeModelCompartment(changeModelCompartmentRequest: requests.ChangeModelCompartmentRequest): Promise<responses.ChangeModelCompartmentResponse>;
    /**
     * Moves a model deployment into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeModelDeploymentCompartmentRequest
     * @return ChangeModelDeploymentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeModelDeploymentCompartment.ts.html |here} to see how to use ChangeModelDeploymentCompartment API.
     */
    changeModelDeploymentCompartment(changeModelDeploymentCompartmentRequest: requests.ChangeModelDeploymentCompartmentRequest): Promise<responses.ChangeModelDeploymentCompartmentResponse>;
    /**
     * Moves a modelVersionSet resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeModelVersionSetCompartmentRequest
     * @return ChangeModelVersionSetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeModelVersionSetCompartment.ts.html |here} to see how to use ChangeModelVersionSetCompartment API.
     */
    changeModelVersionSetCompartment(changeModelVersionSetCompartmentRequest: requests.ChangeModelVersionSetCompartmentRequest): Promise<responses.ChangeModelVersionSetCompartmentResponse>;
    /**
     * Moves a notebook session resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeNotebookSessionCompartmentRequest
     * @return ChangeNotebookSessionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeNotebookSessionCompartment.ts.html |here} to see how to use ChangeNotebookSessionCompartment API.
     */
    changeNotebookSessionCompartment(changeNotebookSessionCompartmentRequest: requests.ChangeNotebookSessionCompartmentRequest): Promise<responses.ChangeNotebookSessionCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangePipelineCompartmentRequest
     * @return ChangePipelineCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangePipelineCompartment.ts.html |here} to see how to use ChangePipelineCompartment API.
     */
    changePipelineCompartment(changePipelineCompartmentRequest: requests.ChangePipelineCompartmentRequest): Promise<responses.ChangePipelineCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangePipelineRunCompartmentRequest
     * @return ChangePipelineRunCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangePipelineRunCompartment.ts.html |here} to see how to use ChangePipelineRunCompartment API.
     */
    changePipelineRunCompartment(changePipelineRunCompartmentRequest: requests.ChangePipelineRunCompartmentRequest): Promise<responses.ChangePipelineRunCompartmentResponse>;
    /**
     * Moves a project resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeProjectCompartmentRequest
     * @return ChangeProjectCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeProjectCompartment.ts.html |here} to see how to use ChangeProjectCompartment API.
     */
    changeProjectCompartment(changeProjectCompartmentRequest: requests.ChangeProjectCompartmentRequest): Promise<responses.ChangeProjectCompartmentResponse>;
    /**
     * Moves a Schedule resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeScheduleCompartmentRequest
     * @return ChangeScheduleCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ChangeScheduleCompartment.ts.html |here} to see how to use ChangeScheduleCompartment API.
     */
    changeScheduleCompartment(changeScheduleCompartmentRequest: requests.ChangeScheduleCompartmentRequest): Promise<responses.ChangeScheduleCompartmentResponse>;
    /**
     * Creates a Data Science private endpoint to be used by a Data Science resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDataSciencePrivateEndpointRequest
     * @return CreateDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateDataSciencePrivateEndpoint.ts.html |here} to see how to use CreateDataSciencePrivateEndpoint API.
     */
    createDataSciencePrivateEndpoint(createDataSciencePrivateEndpointRequest: requests.CreateDataSciencePrivateEndpointRequest): Promise<responses.CreateDataSciencePrivateEndpointResponse>;
    /**
     * Creates a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJobRequest
     * @return CreateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateJob.ts.html |here} to see how to use CreateJob API.
     */
    createJob(createJobRequest: requests.CreateJobRequest): Promise<responses.CreateJobResponse>;
    /**
     * Uploads a job artifact.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateJobArtifactRequest
     * @return CreateJobArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateJobArtifact.ts.html |here} to see how to use CreateJobArtifact API.
     */
    createJobArtifact(createJobArtifactRequest: requests.CreateJobArtifactRequest): Promise<responses.CreateJobArtifactResponse>;
    /**
     * Creates a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJobRunRequest
     * @return CreateJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateJobRun.ts.html |here} to see how to use CreateJobRun API.
     */
    createJobRun(createJobRunRequest: requests.CreateJobRunRequest): Promise<responses.CreateJobRunResponse>;
    /**
     * Creates a new MlApplication.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMlApplicationRequest
     * @return CreateMlApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateMlApplication.ts.html |here} to see how to use CreateMlApplication API.
     */
    createMlApplication(createMlApplicationRequest: requests.CreateMlApplicationRequest): Promise<responses.CreateMlApplicationResponse>;
    /**
     * Creates a new MlApplicationImplementation.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMlApplicationImplementationRequest
     * @return CreateMlApplicationImplementationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateMlApplicationImplementation.ts.html |here} to see how to use CreateMlApplicationImplementation API.
     */
    createMlApplicationImplementation(createMlApplicationImplementationRequest: requests.CreateMlApplicationImplementationRequest): Promise<responses.CreateMlApplicationImplementationResponse>;
    /**
     * Creates a new MlApplicationInstance.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMlApplicationInstanceRequest
     * @return CreateMlApplicationInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateMlApplicationInstance.ts.html |here} to see how to use CreateMlApplicationInstance API.
     */
    createMlApplicationInstance(createMlApplicationInstanceRequest: requests.CreateMlApplicationInstanceRequest): Promise<responses.CreateMlApplicationInstanceResponse>;
    /**
     * Creates a new model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelRequest
     * @return CreateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModel.ts.html |here} to see how to use CreateModel API.
     */
    createModel(createModelRequest: requests.CreateModelRequest): Promise<responses.CreateModelResponse>;
    /**
     * Creates model artifact for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelArtifactRequest
     * @return CreateModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModelArtifact.ts.html |here} to see how to use CreateModelArtifact API.
     */
    createModelArtifact(createModelArtifactRequest: requests.CreateModelArtifactRequest): Promise<responses.CreateModelArtifactResponse>;
    /**
     * Creates model custom metadata artifact for specified model.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateModelCustomMetadatumArtifactRequest
     * @return CreateModelCustomMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModelCustomMetadatumArtifact.ts.html |here} to see how to use CreateModelCustomMetadatumArtifact API.
     */
    createModelCustomMetadatumArtifact(createModelCustomMetadatumArtifactRequest: requests.CreateModelCustomMetadatumArtifactRequest): Promise<responses.CreateModelCustomMetadatumArtifactResponse>;
    /**
     * Creates model defined metadata artifact for specified model.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateModelDefinedMetadatumArtifactRequest
     * @return CreateModelDefinedMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModelDefinedMetadatumArtifact.ts.html |here} to see how to use CreateModelDefinedMetadatumArtifact API.
     */
    createModelDefinedMetadatumArtifact(createModelDefinedMetadatumArtifactRequest: requests.CreateModelDefinedMetadatumArtifactRequest): Promise<responses.CreateModelDefinedMetadatumArtifactResponse>;
    /**
     * Creates a new model deployment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelDeploymentRequest
     * @return CreateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModelDeployment.ts.html |here} to see how to use CreateModelDeployment API.
     */
    createModelDeployment(createModelDeploymentRequest: requests.CreateModelDeploymentRequest): Promise<responses.CreateModelDeploymentResponse>;
    /**
     * Creates provenance information for the specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelProvenanceRequest
     * @return CreateModelProvenanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModelProvenance.ts.html |here} to see how to use CreateModelProvenance API.
     */
    createModelProvenance(createModelProvenanceRequest: requests.CreateModelProvenanceRequest): Promise<responses.CreateModelProvenanceResponse>;
    /**
     * Creates a new modelVersionSet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelVersionSetRequest
     * @return CreateModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateModelVersionSet.ts.html |here} to see how to use CreateModelVersionSet API.
     */
    createModelVersionSet(createModelVersionSetRequest: requests.CreateModelVersionSetRequest): Promise<responses.CreateModelVersionSetResponse>;
    /**
     * Creates a new notebook session.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateNotebookSessionRequest
     * @return CreateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateNotebookSession.ts.html |here} to see how to use CreateNotebookSession API.
     */
    createNotebookSession(createNotebookSessionRequest: requests.CreateNotebookSessionRequest): Promise<responses.CreateNotebookSessionResponse>;
    /**
     * Creates a new Pipeline.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePipelineRequest
     * @return CreatePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreatePipeline.ts.html |here} to see how to use CreatePipeline API.
     */
    createPipeline(createPipelineRequest: requests.CreatePipelineRequest): Promise<responses.CreatePipelineResponse>;
    /**
     * Creates a new PipelineRun.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePipelineRunRequest
     * @return CreatePipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreatePipelineRun.ts.html |here} to see how to use CreatePipelineRun API.
     */
    createPipelineRun(createPipelineRunRequest: requests.CreatePipelineRunRequest): Promise<responses.CreatePipelineRunResponse>;
    /**
     * Creates a new project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Creates a new Schedule.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateScheduleRequest
     * @return CreateScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateSchedule.ts.html |here} to see how to use CreateSchedule API.
     */
    createSchedule(createScheduleRequest: requests.CreateScheduleRequest): Promise<responses.CreateScheduleResponse>;
    /**
     * Upload the artifact for a step in the pipeline.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateStepArtifactRequest
     * @return CreateStepArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/CreateStepArtifact.ts.html |here} to see how to use CreateStepArtifact API.
     */
    createStepArtifact(createStepArtifactRequest: requests.CreateStepArtifactRequest): Promise<responses.CreateStepArtifactResponse>;
    /**
     * Deactivates the model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeactivateModelRequest
     * @return DeactivateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeactivateModel.ts.html |here} to see how to use DeactivateModel API.
     */
    deactivateModel(deactivateModelRequest: requests.DeactivateModelRequest): Promise<responses.DeactivateModelResponse>;
    /**
     * Deactivates the model deployment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeactivateModelDeploymentRequest
     * @return DeactivateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeactivateModelDeployment.ts.html |here} to see how to use DeactivateModelDeployment API.
     */
    deactivateModelDeployment(deactivateModelDeploymentRequest: requests.DeactivateModelDeploymentRequest): Promise<responses.DeactivateModelDeploymentResponse>;
    /**
     * Deactivates the notebook session.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeactivateNotebookSessionRequest
     * @return DeactivateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeactivateNotebookSession.ts.html |here} to see how to use DeactivateNotebookSession API.
     */
    deactivateNotebookSession(deactivateNotebookSessionRequest: requests.DeactivateNotebookSessionRequest): Promise<responses.DeactivateNotebookSessionResponse>;
    /**
     * Deactivate schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeactivateScheduleRequest
     * @return DeactivateScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeactivateSchedule.ts.html |here} to see how to use DeactivateSchedule API.
     */
    deactivateSchedule(deactivateScheduleRequest: requests.DeactivateScheduleRequest): Promise<responses.DeactivateScheduleResponse>;
    /**
     * Deletes a private endpoint using `privateEndpointId`.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataSciencePrivateEndpointRequest
     * @return DeleteDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteDataSciencePrivateEndpoint.ts.html |here} to see how to use DeleteDataSciencePrivateEndpoint API.
     */
    deleteDataSciencePrivateEndpoint(deleteDataSciencePrivateEndpointRequest: requests.DeleteDataSciencePrivateEndpointRequest): Promise<responses.DeleteDataSciencePrivateEndpointResponse>;
    /**
     * Deletes a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJobRequest
     * @return DeleteJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteJob.ts.html |here} to see how to use DeleteJob API.
     */
    deleteJob(deleteJobRequest: requests.DeleteJobRequest): Promise<responses.DeleteJobResponse>;
    /**
     * Deletes a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJobRunRequest
     * @return DeleteJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteJobRun.ts.html |here} to see how to use DeleteJobRun API.
     */
    deleteJobRun(deleteJobRunRequest: requests.DeleteJobRunRequest): Promise<responses.DeleteJobRunResponse>;
    /**
     * Deletes a MlApplication resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMlApplicationRequest
     * @return DeleteMlApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteMlApplication.ts.html |here} to see how to use DeleteMlApplication API.
     */
    deleteMlApplication(deleteMlApplicationRequest: requests.DeleteMlApplicationRequest): Promise<responses.DeleteMlApplicationResponse>;
    /**
     * Deletes a MlApplicationImplementation resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMlApplicationImplementationRequest
     * @return DeleteMlApplicationImplementationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteMlApplicationImplementation.ts.html |here} to see how to use DeleteMlApplicationImplementation API.
     */
    deleteMlApplicationImplementation(deleteMlApplicationImplementationRequest: requests.DeleteMlApplicationImplementationRequest): Promise<responses.DeleteMlApplicationImplementationResponse>;
    /**
     * Deletes a MlApplicationInstance resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMlApplicationInstanceRequest
     * @return DeleteMlApplicationInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteMlApplicationInstance.ts.html |here} to see how to use DeleteMlApplicationInstance API.
     */
    deleteMlApplicationInstance(deleteMlApplicationInstanceRequest: requests.DeleteMlApplicationInstanceRequest): Promise<responses.DeleteMlApplicationInstanceResponse>;
    /**
     * Deletes the specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelRequest
     * @return DeleteModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteModel.ts.html |here} to see how to use DeleteModel API.
     */
    deleteModel(deleteModelRequest: requests.DeleteModelRequest): Promise<responses.DeleteModelResponse>;
    /**
     * Deletes model custom metadata artifact for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelCustomMetadatumArtifactRequest
     * @return DeleteModelCustomMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteModelCustomMetadatumArtifact.ts.html |here} to see how to use DeleteModelCustomMetadatumArtifact API.
     */
    deleteModelCustomMetadatumArtifact(deleteModelCustomMetadatumArtifactRequest: requests.DeleteModelCustomMetadatumArtifactRequest): Promise<responses.DeleteModelCustomMetadatumArtifactResponse>;
    /**
     * Deletes model defined metadata artifact for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelDefinedMetadatumArtifactRequest
     * @return DeleteModelDefinedMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteModelDefinedMetadatumArtifact.ts.html |here} to see how to use DeleteModelDefinedMetadatumArtifact API.
     */
    deleteModelDefinedMetadatumArtifact(deleteModelDefinedMetadatumArtifactRequest: requests.DeleteModelDefinedMetadatumArtifactRequest): Promise<responses.DeleteModelDefinedMetadatumArtifactResponse>;
    /**
     * Deletes the specified model deployment. Any unsaved work in this model deployment is lost.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelDeploymentRequest
     * @return DeleteModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteModelDeployment.ts.html |here} to see how to use DeleteModelDeployment API.
     */
    deleteModelDeployment(deleteModelDeploymentRequest: requests.DeleteModelDeploymentRequest): Promise<responses.DeleteModelDeploymentResponse>;
    /**
     * Deletes the specified modelVersionSet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelVersionSetRequest
     * @return DeleteModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteModelVersionSet.ts.html |here} to see how to use DeleteModelVersionSet API.
     */
    deleteModelVersionSet(deleteModelVersionSetRequest: requests.DeleteModelVersionSetRequest): Promise<responses.DeleteModelVersionSetResponse>;
    /**
     * Deletes the specified notebook session. Any unsaved work in this notebook session are lost.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteNotebookSessionRequest
     * @return DeleteNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteNotebookSession.ts.html |here} to see how to use DeleteNotebookSession API.
     */
    deleteNotebookSession(deleteNotebookSessionRequest: requests.DeleteNotebookSessionRequest): Promise<responses.DeleteNotebookSessionResponse>;
    /**
     * Deletes a Pipeline resource by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePipelineRequest
     * @return DeletePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeletePipeline.ts.html |here} to see how to use DeletePipeline API.
     */
    deletePipeline(deletePipelineRequest: requests.DeletePipelineRequest): Promise<responses.DeletePipelineResponse>;
    /**
     * Deletes a PipelineRun resource by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePipelineRunRequest
     * @return DeletePipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeletePipelineRun.ts.html |here} to see how to use DeletePipelineRun API.
     */
    deletePipelineRun(deletePipelineRunRequest: requests.DeletePipelineRunRequest): Promise<responses.DeletePipelineRunResponse>;
    /**
     * Deletes the specified project. This operation fails unless all associated resources (notebook sessions or models) are in a DELETED state. You must delete all associated resources before deleting a project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
     * Deletes a Schedule resource by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteScheduleRequest
     * @return DeleteScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DeleteSchedule.ts.html |here} to see how to use DeleteSchedule API.
     */
    deleteSchedule(deleteScheduleRequest: requests.DeleteScheduleRequest): Promise<responses.DeleteScheduleResponse>;
    /**
     * Disable trigger of given name for given ML Application Instance View flow
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableMlApplicationInstanceViewTriggerRequest
     * @return DisableMlApplicationInstanceViewTriggerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/DisableMlApplicationInstanceViewTrigger.ts.html |here} to see how to use DisableMlApplicationInstanceViewTrigger API.
     */
    disableMlApplicationInstanceViewTrigger(disableMlApplicationInstanceViewTriggerRequest: requests.DisableMlApplicationInstanceViewTriggerRequest): Promise<responses.DisableMlApplicationInstanceViewTriggerResponse>;
    /**
     * Enable trigger of given name for given ML Application Instance View flow
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableMlApplicationInstanceViewTriggerRequest
     * @return EnableMlApplicationInstanceViewTriggerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/EnableMlApplicationInstanceViewTrigger.ts.html |here} to see how to use EnableMlApplicationInstanceViewTrigger API.
     */
    enableMlApplicationInstanceViewTrigger(enableMlApplicationInstanceViewTriggerRequest: requests.EnableMlApplicationInstanceViewTriggerRequest): Promise<responses.EnableMlApplicationInstanceViewTriggerResponse>;
    /**
     * Export model artifact from source to the service bucket
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ExportModelArtifactRequest
     * @return ExportModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ExportModelArtifact.ts.html |here} to see how to use ExportModelArtifact API.
     */
    exportModelArtifact(exportModelArtifactRequest: requests.ExportModelArtifactRequest): Promise<responses.ExportModelArtifactResponse>;
    /**
     * Retrieves an private endpoint using a `privateEndpointId`.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDataSciencePrivateEndpointRequest
     * @return GetDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetDataSciencePrivateEndpoint.ts.html |here} to see how to use GetDataSciencePrivateEndpoint API.
     */
    getDataSciencePrivateEndpoint(getDataSciencePrivateEndpointRequest: requests.GetDataSciencePrivateEndpointRequest): Promise<responses.GetDataSciencePrivateEndpointResponse>;
    /**
     * Gets a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobRequest
     * @return GetJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetJob.ts.html |here} to see how to use GetJob API.
     */
    getJob(getJobRequest: requests.GetJobRequest): Promise<responses.GetJobResponse>;
    /**
     * Downloads job artifact content for specified job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobArtifactContentRequest
     * @return GetJobArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetJobArtifactContent.ts.html |here} to see how to use GetJobArtifactContent API.
     */
    getJobArtifactContent(getJobArtifactContentRequest: requests.GetJobArtifactContentRequest): Promise<responses.GetJobArtifactContentResponse>;
    /**
     * Gets a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobRunRequest
     * @return GetJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetJobRun.ts.html |here} to see how to use GetJobRun API.
     */
    getJobRun(getJobRunRequest: requests.GetJobRunRequest): Promise<responses.GetJobRunResponse>;
    /**
     * Gets a MlApplication by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationRequest
     * @return GetMlApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplication.ts.html |here} to see how to use GetMlApplication API.
     */
    getMlApplication(getMlApplicationRequest: requests.GetMlApplicationRequest): Promise<responses.GetMlApplicationResponse>;
    /**
     * Retrieves ML Application package for MlApplicationImplementationVersion with given id.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationHistoricalPackageContentRequest
     * @return GetMlApplicationHistoricalPackageContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplicationHistoricalPackageContent.ts.html |here} to see how to use GetMlApplicationHistoricalPackageContent API.
     */
    getMlApplicationHistoricalPackageContent(getMlApplicationHistoricalPackageContentRequest: requests.GetMlApplicationHistoricalPackageContentRequest): Promise<responses.GetMlApplicationHistoricalPackageContentResponse>;
    /**
     * Gets a MlApplicationImplementation by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationImplementationRequest
     * @return GetMlApplicationImplementationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplicationImplementation.ts.html |here} to see how to use GetMlApplicationImplementation API.
     */
    getMlApplicationImplementation(getMlApplicationImplementationRequest: requests.GetMlApplicationImplementationRequest): Promise<responses.GetMlApplicationImplementationResponse>;
    /**
     * Gets a MlApplicationImplementationVersion by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationImplementationVersionRequest
     * @return GetMlApplicationImplementationVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplicationImplementationVersion.ts.html |here} to see how to use GetMlApplicationImplementationVersion API.
     */
    getMlApplicationImplementationVersion(getMlApplicationImplementationVersionRequest: requests.GetMlApplicationImplementationVersionRequest): Promise<responses.GetMlApplicationImplementationVersionResponse>;
    /**
     * Gets a MlApplicationInstance by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationInstanceRequest
     * @return GetMlApplicationInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplicationInstance.ts.html |here} to see how to use GetMlApplicationInstance API.
     */
    getMlApplicationInstance(getMlApplicationInstanceRequest: requests.GetMlApplicationInstanceRequest): Promise<responses.GetMlApplicationInstanceResponse>;
    /**
     * Gets a MlApplicationInstanceView by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationInstanceViewRequest
     * @return GetMlApplicationInstanceViewResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplicationInstanceView.ts.html |here} to see how to use GetMlApplicationInstanceView API.
     */
    getMlApplicationInstanceView(getMlApplicationInstanceViewRequest: requests.GetMlApplicationInstanceViewRequest): Promise<responses.GetMlApplicationInstanceViewResponse>;
    /**
     * Retrieves last ML Application package uploaded for given ML Application Implementation
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMlApplicationPackageContentRequest
     * @return GetMlApplicationPackageContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetMlApplicationPackageContent.ts.html |here} to see how to use GetMlApplicationPackageContent API.
     */
    getMlApplicationPackageContent(getMlApplicationPackageContentRequest: requests.GetMlApplicationPackageContentRequest): Promise<responses.GetMlApplicationPackageContentResponse>;
    /**
     * Gets the specified model's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelRequest
     * @return GetModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModel.ts.html |here} to see how to use GetModel API.
     */
    getModel(getModelRequest: requests.GetModelRequest): Promise<responses.GetModelResponse>;
    /**
     * Downloads model artifact content for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelArtifactContentRequest
     * @return GetModelArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModelArtifactContent.ts.html |here} to see how to use GetModelArtifactContent API.
     */
    getModelArtifactContent(getModelArtifactContentRequest: requests.GetModelArtifactContentRequest): Promise<responses.GetModelArtifactContentResponse>;
    /**
     * Downloads model custom metadata artifact content for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelCustomMetadatumArtifactContentRequest
     * @return GetModelCustomMetadatumArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModelCustomMetadatumArtifactContent.ts.html |here} to see how to use GetModelCustomMetadatumArtifactContent API.
     */
    getModelCustomMetadatumArtifactContent(getModelCustomMetadatumArtifactContentRequest: requests.GetModelCustomMetadatumArtifactContentRequest): Promise<responses.GetModelCustomMetadatumArtifactContentResponse>;
    /**
     * Downloads model defined metadata artifact content for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelDefinedMetadatumArtifactContentRequest
     * @return GetModelDefinedMetadatumArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModelDefinedMetadatumArtifactContent.ts.html |here} to see how to use GetModelDefinedMetadatumArtifactContent API.
     */
    getModelDefinedMetadatumArtifactContent(getModelDefinedMetadatumArtifactContentRequest: requests.GetModelDefinedMetadatumArtifactContentRequest): Promise<responses.GetModelDefinedMetadatumArtifactContentResponse>;
    /**
     * Retrieves the model deployment for the specified `modelDeploymentId`.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelDeploymentRequest
     * @return GetModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModelDeployment.ts.html |here} to see how to use GetModelDeployment API.
     */
    getModelDeployment(getModelDeploymentRequest: requests.GetModelDeploymentRequest): Promise<responses.GetModelDeploymentResponse>;
    /**
     * Gets provenance information for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelProvenanceRequest
     * @return GetModelProvenanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModelProvenance.ts.html |here} to see how to use GetModelProvenance API.
     */
    getModelProvenance(getModelProvenanceRequest: requests.GetModelProvenanceRequest): Promise<responses.GetModelProvenanceResponse>;
    /**
     * Gets the specified model version set information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelVersionSetRequest
     * @return GetModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetModelVersionSet.ts.html |here} to see how to use GetModelVersionSet API.
     */
    getModelVersionSet(getModelVersionSetRequest: requests.GetModelVersionSetRequest): Promise<responses.GetModelVersionSetResponse>;
    /**
     * Gets the specified notebook session's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetNotebookSessionRequest
     * @return GetNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetNotebookSession.ts.html |here} to see how to use GetNotebookSession API.
     */
    getNotebookSession(getNotebookSessionRequest: requests.GetNotebookSessionRequest): Promise<responses.GetNotebookSessionResponse>;
    /**
     * Gets a Pipeline by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPipelineRequest
     * @return GetPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetPipeline.ts.html |here} to see how to use GetPipeline API.
     */
    getPipeline(getPipelineRequest: requests.GetPipelineRequest): Promise<responses.GetPipelineResponse>;
    /**
     * Gets a PipelineRun by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPipelineRunRequest
     * @return GetPipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetPipelineRun.ts.html |here} to see how to use GetPipelineRun API.
     */
    getPipelineRun(getPipelineRunRequest: requests.GetPipelineRunRequest): Promise<responses.GetPipelineRunResponse>;
    /**
     * Gets the specified project's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * Gets a Schedule by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetScheduleRequest
     * @return GetScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetSchedule.ts.html |here} to see how to use GetSchedule API.
     */
    getSchedule(getScheduleRequest: requests.GetScheduleRequest): Promise<responses.GetScheduleResponse>;
    /**
     * Download the artifact for a step in the pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetStepArtifactContentRequest
     * @return GetStepArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetStepArtifactContent.ts.html |here} to see how to use GetStepArtifactContent API.
     */
    getStepArtifactContent(getStepArtifactContentRequest: requests.GetStepArtifactContentRequest): Promise<responses.GetStepArtifactContentResponse>;
    /**
     * Gets the specified work request's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets job artifact metadata.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadJobArtifactRequest
     * @return HeadJobArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/HeadJobArtifact.ts.html |here} to see how to use HeadJobArtifact API.
     */
    headJobArtifact(headJobArtifactRequest: requests.HeadJobArtifactRequest): Promise<responses.HeadJobArtifactResponse>;
    /**
     * Gets model artifact metadata for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadModelArtifactRequest
     * @return HeadModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/HeadModelArtifact.ts.html |here} to see how to use HeadModelArtifact API.
     */
    headModelArtifact(headModelArtifactRequest: requests.HeadModelArtifactRequest): Promise<responses.HeadModelArtifactResponse>;
    /**
     * Gets custom metadata artifact metadata for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadModelCustomMetadatumArtifactRequest
     * @return HeadModelCustomMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/HeadModelCustomMetadatumArtifact.ts.html |here} to see how to use HeadModelCustomMetadatumArtifact API.
     */
    headModelCustomMetadatumArtifact(headModelCustomMetadatumArtifactRequest: requests.HeadModelCustomMetadatumArtifactRequest): Promise<responses.HeadModelCustomMetadatumArtifactResponse>;
    /**
     * Gets defined metadata artifact metadata for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadModelDefinedMetadatumArtifactRequest
     * @return HeadModelDefinedMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/HeadModelDefinedMetadatumArtifact.ts.html |here} to see how to use HeadModelDefinedMetadatumArtifact API.
     */
    headModelDefinedMetadatumArtifact(headModelDefinedMetadatumArtifactRequest: requests.HeadModelDefinedMetadatumArtifactRequest): Promise<responses.HeadModelDefinedMetadatumArtifactResponse>;
    /**
     * Get the artifact metadata for a step in the pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadStepArtifactRequest
     * @return HeadStepArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/HeadStepArtifact.ts.html |here} to see how to use HeadStepArtifact API.
     */
    headStepArtifact(headStepArtifactRequest: requests.HeadStepArtifactRequest): Promise<responses.HeadStepArtifactResponse>;
    /**
     * Import model artifact from service bucket
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ImportModelArtifactRequest
     * @return ImportModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ImportModelArtifact.ts.html |here} to see how to use ImportModelArtifact API.
     */
    importModelArtifact(importModelArtifactRequest: requests.ImportModelArtifactRequest): Promise<responses.ImportModelArtifactResponse>;
    /**
     * List containers.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListContainersRequest
     * @return ListContainersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListContainers.ts.html |here} to see how to use ListContainers API.
     */
    listContainers(listContainersRequest: requests.ListContainersRequest): Promise<responses.ListContainersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listContainersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ContainerSummary objects
     * contained in responses from the listContainers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllContainers(request: requests.ListContainersRequest): AsyncIterableIterator<model.ContainerSummary>;
    /**
     * NOTE: This function is deprecated in favor of listContainersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listContainers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllContainersResponses(request: requests.ListContainersRequest): AsyncIterableIterator<responses.ListContainersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ContainerSummary objects
     * contained in responses from the listContainers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listContainersRecordIterator(request: requests.ListContainersRequest): AsyncIterableIterator<model.ContainerSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listContainers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listContainersResponseIterator(request: requests.ListContainersRequest): AsyncIterableIterator<responses.ListContainersResponse>;
    /**
     * Lists all Data Science private endpoints in the specified compartment. The query must include compartmentId. The query can also include one other parameter. If the query doesn't include compartmentId, or includes compartmentId with two or more other parameters, then an error is returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDataSciencePrivateEndpointsRequest
     * @return ListDataSciencePrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListDataSciencePrivateEndpoints.ts.html |here} to see how to use ListDataSciencePrivateEndpoints API.
     */
    listDataSciencePrivateEndpoints(listDataSciencePrivateEndpointsRequest: requests.ListDataSciencePrivateEndpointsRequest): Promise<responses.ListDataSciencePrivateEndpointsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDataSciencePrivateEndpointsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DataSciencePrivateEndpointSummary objects
     * contained in responses from the listDataSciencePrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataSciencePrivateEndpoints(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<model.DataSciencePrivateEndpointSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDataSciencePrivateEndpointsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDataSciencePrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataSciencePrivateEndpointsResponses(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<responses.ListDataSciencePrivateEndpointsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DataSciencePrivateEndpointSummary objects
     * contained in responses from the listDataSciencePrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataSciencePrivateEndpointsRecordIterator(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<model.DataSciencePrivateEndpointSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDataSciencePrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataSciencePrivateEndpointsResponseIterator(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<responses.ListDataSciencePrivateEndpointsResponse>;
    /**
     * List fast launch capable job configs in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFastLaunchJobConfigsRequest
     * @return ListFastLaunchJobConfigsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListFastLaunchJobConfigs.ts.html |here} to see how to use ListFastLaunchJobConfigs API.
     */
    listFastLaunchJobConfigs(listFastLaunchJobConfigsRequest: requests.ListFastLaunchJobConfigsRequest): Promise<responses.ListFastLaunchJobConfigsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listFastLaunchJobConfigsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.FastLaunchJobConfigSummary objects
     * contained in responses from the listFastLaunchJobConfigs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastLaunchJobConfigs(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<model.FastLaunchJobConfigSummary>;
    /**
     * NOTE: This function is deprecated in favor of listFastLaunchJobConfigsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listFastLaunchJobConfigs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastLaunchJobConfigsResponses(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<responses.ListFastLaunchJobConfigsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.FastLaunchJobConfigSummary objects
     * contained in responses from the listFastLaunchJobConfigs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastLaunchJobConfigsRecordIterator(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<model.FastLaunchJobConfigSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listFastLaunchJobConfigs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastLaunchJobConfigsResponseIterator(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<responses.ListFastLaunchJobConfigsResponse>;
    /**
     * List out job runs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJobRunsRequest
     * @return ListJobRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListJobRuns.ts.html |here} to see how to use ListJobRuns API.
     */
    listJobRuns(listJobRunsRequest: requests.ListJobRunsRequest): Promise<responses.ListJobRunsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listJobRunsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.JobRunSummary objects
     * contained in responses from the listJobRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobRuns(request: requests.ListJobRunsRequest): AsyncIterableIterator<model.JobRunSummary>;
    /**
     * NOTE: This function is deprecated in favor of listJobRunsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listJobRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobRunsResponses(request: requests.ListJobRunsRequest): AsyncIterableIterator<responses.ListJobRunsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.JobRunSummary objects
     * contained in responses from the listJobRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobRunsRecordIterator(request: requests.ListJobRunsRequest): AsyncIterableIterator<model.JobRunSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listJobRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobRunsResponseIterator(request: requests.ListJobRunsRequest): AsyncIterableIterator<responses.ListJobRunsResponse>;
    /**
     * List job shapes available in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJobShapesRequest
     * @return ListJobShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListJobShapes.ts.html |here} to see how to use ListJobShapes API.
     */
    listJobShapes(listJobShapesRequest: requests.ListJobShapesRequest): Promise<responses.ListJobShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listJobShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.JobShapeSummary objects
     * contained in responses from the listJobShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobShapes(request: requests.ListJobShapesRequest): AsyncIterableIterator<model.JobShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listJobShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listJobShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobShapesResponses(request: requests.ListJobShapesRequest): AsyncIterableIterator<responses.ListJobShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.JobShapeSummary objects
     * contained in responses from the listJobShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobShapesRecordIterator(request: requests.ListJobShapesRequest): AsyncIterableIterator<model.JobShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listJobShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobShapesResponseIterator(request: requests.ListJobShapesRequest): AsyncIterableIterator<responses.ListJobShapesResponse>;
    /**
     * List jobs in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJobsRequest
     * @return ListJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListJobs.ts.html |here} to see how to use ListJobs API.
     */
    listJobs(listJobsRequest: requests.ListJobsRequest): Promise<responses.ListJobsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listJobsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.JobSummary objects
     * contained in responses from the listJobs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobs(request: requests.ListJobsRequest): AsyncIterableIterator<model.JobSummary>;
    /**
     * NOTE: This function is deprecated in favor of listJobsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listJobs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobsResponses(request: requests.ListJobsRequest): AsyncIterableIterator<responses.ListJobsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.JobSummary objects
     * contained in responses from the listJobs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobsRecordIterator(request: requests.ListJobsRequest): AsyncIterableIterator<model.JobSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listJobs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobsResponseIterator(request: requests.ListJobsRequest): AsyncIterableIterator<responses.ListJobsResponse>;
    /**
     * Returns a list of MlApplicationImplementationVersions.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMlApplicationImplementationVersionsRequest
     * @return ListMlApplicationImplementationVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListMlApplicationImplementationVersions.ts.html |here} to see how to use ListMlApplicationImplementationVersions API.
     */
    listMlApplicationImplementationVersions(listMlApplicationImplementationVersionsRequest: requests.ListMlApplicationImplementationVersionsRequest): Promise<responses.ListMlApplicationImplementationVersionsResponse>;
    /**
     * Returns a list of MlApplicationImplementations.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMlApplicationImplementationsRequest
     * @return ListMlApplicationImplementationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListMlApplicationImplementations.ts.html |here} to see how to use ListMlApplicationImplementations API.
     */
    listMlApplicationImplementations(listMlApplicationImplementationsRequest: requests.ListMlApplicationImplementationsRequest): Promise<responses.ListMlApplicationImplementationsResponse>;
    /**
     * Returns a list of MlApplicationInstanceViews.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMlApplicationInstanceViewsRequest
     * @return ListMlApplicationInstanceViewsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListMlApplicationInstanceViews.ts.html |here} to see how to use ListMlApplicationInstanceViews API.
     */
    listMlApplicationInstanceViews(listMlApplicationInstanceViewsRequest: requests.ListMlApplicationInstanceViewsRequest): Promise<responses.ListMlApplicationInstanceViewsResponse>;
    /**
     * Returns a list of MlApplicationsInstances.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMlApplicationInstancesRequest
     * @return ListMlApplicationInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListMlApplicationInstances.ts.html |here} to see how to use ListMlApplicationInstances API.
     */
    listMlApplicationInstances(listMlApplicationInstancesRequest: requests.ListMlApplicationInstancesRequest): Promise<responses.ListMlApplicationInstancesResponse>;
    /**
     * Returns a list of MlApplications.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMlApplicationsRequest
     * @return ListMlApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListMlApplications.ts.html |here} to see how to use ListMlApplications API.
     */
    listMlApplications(listMlApplicationsRequest: requests.ListMlApplicationsRequest): Promise<responses.ListMlApplicationsResponse>;
    /**
     * Lists the valid model deployment shapes.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelDeploymentShapesRequest
     * @return ListModelDeploymentShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListModelDeploymentShapes.ts.html |here} to see how to use ListModelDeploymentShapes API.
     */
    listModelDeploymentShapes(listModelDeploymentShapesRequest: requests.ListModelDeploymentShapesRequest): Promise<responses.ListModelDeploymentShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelDeploymentShapeSummary objects
     * contained in responses from the listModelDeploymentShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeploymentShapes(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<model.ModelDeploymentShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModelDeploymentShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeploymentShapesResponses(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<responses.ListModelDeploymentShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelDeploymentShapeSummary objects
     * contained in responses from the listModelDeploymentShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentShapesRecordIterator(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<model.ModelDeploymentShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModelDeploymentShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentShapesResponseIterator(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<responses.ListModelDeploymentShapesResponse>;
    /**
     * Lists all model deployments in the specified compartment. Only one parameter other than compartmentId may also be included in a query. The query must include compartmentId. If the query does not include compartmentId, or includes compartmentId but two or more other parameters an error is returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelDeploymentsRequest
     * @return ListModelDeploymentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListModelDeployments.ts.html |here} to see how to use ListModelDeployments API.
     */
    listModelDeployments(listModelDeploymentsRequest: requests.ListModelDeploymentsRequest): Promise<responses.ListModelDeploymentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelDeploymentSummary objects
     * contained in responses from the listModelDeployments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeployments(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<model.ModelDeploymentSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModelDeployments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeploymentsResponses(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<responses.ListModelDeploymentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelDeploymentSummary objects
     * contained in responses from the listModelDeployments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentsRecordIterator(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<model.ModelDeploymentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModelDeployments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentsResponseIterator(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<responses.ListModelDeploymentsResponse>;
    /**
     * Lists model version sets in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelVersionSetsRequest
     * @return ListModelVersionSetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListModelVersionSets.ts.html |here} to see how to use ListModelVersionSets API.
     */
    listModelVersionSets(listModelVersionSetsRequest: requests.ListModelVersionSetsRequest): Promise<responses.ListModelVersionSetsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelVersionSetsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelVersionSetSummary objects
     * contained in responses from the listModelVersionSets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelVersionSets(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<model.ModelVersionSetSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelVersionSetsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModelVersionSets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelVersionSetsResponses(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<responses.ListModelVersionSetsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelVersionSetSummary objects
     * contained in responses from the listModelVersionSets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelVersionSetsRecordIterator(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<model.ModelVersionSetSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModelVersionSets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelVersionSetsResponseIterator(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<responses.ListModelVersionSetsResponse>;
    /**
     * Lists models in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelsRequest
     * @return ListModelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListModels.ts.html |here} to see how to use ListModels API.
     */
    listModels(listModelsRequest: requests.ListModelsRequest): Promise<responses.ListModelsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelSummary objects
     * contained in responses from the listModels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModels(request: requests.ListModelsRequest): AsyncIterableIterator<model.ModelSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelsResponses(request: requests.ListModelsRequest): AsyncIterableIterator<responses.ListModelsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelSummary objects
     * contained in responses from the listModels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelsRecordIterator(request: requests.ListModelsRequest): AsyncIterableIterator<model.ModelSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelsResponseIterator(request: requests.ListModelsRequest): AsyncIterableIterator<responses.ListModelsResponse>;
    /**
     * Lists the valid notebook session shapes.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNotebookSessionShapesRequest
     * @return ListNotebookSessionShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListNotebookSessionShapes.ts.html |here} to see how to use ListNotebookSessionShapes API.
     */
    listNotebookSessionShapes(listNotebookSessionShapesRequest: requests.ListNotebookSessionShapesRequest): Promise<responses.ListNotebookSessionShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NotebookSessionShapeSummary objects
     * contained in responses from the listNotebookSessionShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessionShapes(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<model.NotebookSessionShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessionShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessionShapesResponses(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<responses.ListNotebookSessionShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NotebookSessionShapeSummary objects
     * contained in responses from the listNotebookSessionShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionShapesRecordIterator(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<model.NotebookSessionShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessionShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionShapesResponseIterator(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<responses.ListNotebookSessionShapesResponse>;
    /**
     * Lists the notebook sessions in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNotebookSessionsRequest
     * @return ListNotebookSessionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListNotebookSessions.ts.html |here} to see how to use ListNotebookSessions API.
     */
    listNotebookSessions(listNotebookSessionsRequest: requests.ListNotebookSessionsRequest): Promise<responses.ListNotebookSessionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NotebookSessionSummary objects
     * contained in responses from the listNotebookSessions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessions(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<model.NotebookSessionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessionsResponses(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<responses.ListNotebookSessionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NotebookSessionSummary objects
     * contained in responses from the listNotebookSessions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionsRecordIterator(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<model.NotebookSessionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionsResponseIterator(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<responses.ListNotebookSessionsResponse>;
    /**
     * Returns a list of PipelineRuns.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPipelineRunsRequest
     * @return ListPipelineRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListPipelineRuns.ts.html |here} to see how to use ListPipelineRuns API.
     */
    listPipelineRuns(listPipelineRunsRequest: requests.ListPipelineRunsRequest): Promise<responses.ListPipelineRunsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPipelineRunsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PipelineRunSummary objects
     * contained in responses from the listPipelineRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelineRuns(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<model.PipelineRunSummary>;
    /**
     * NOTE: This function is deprecated in favor of listPipelineRunsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPipelineRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelineRunsResponses(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<responses.ListPipelineRunsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PipelineRunSummary objects
     * contained in responses from the listPipelineRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelineRunsRecordIterator(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<model.PipelineRunSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPipelineRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelineRunsResponseIterator(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<responses.ListPipelineRunsResponse>;
    /**
     * Returns a list of Pipelines.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPipelinesRequest
     * @return ListPipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListPipelines.ts.html |here} to see how to use ListPipelines API.
     */
    listPipelines(listPipelinesRequest: requests.ListPipelinesRequest): Promise<responses.ListPipelinesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPipelinesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PipelineSummary objects
     * contained in responses from the listPipelines operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelines(request: requests.ListPipelinesRequest): AsyncIterableIterator<model.PipelineSummary>;
    /**
     * NOTE: This function is deprecated in favor of listPipelinesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPipelines operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelinesResponses(request: requests.ListPipelinesRequest): AsyncIterableIterator<responses.ListPipelinesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PipelineSummary objects
     * contained in responses from the listPipelines operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelinesRecordIterator(request: requests.ListPipelinesRequest): AsyncIterableIterator<model.PipelineSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPipelines operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelinesResponseIterator(request: requests.ListPipelinesRequest): AsyncIterableIterator<responses.ListPipelinesResponse>;
    /**
     * Lists projects in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listProjectsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ProjectSummary objects
     * contained in responses from the listProjects operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllProjects(request: requests.ListProjectsRequest): AsyncIterableIterator<model.ProjectSummary>;
    /**
     * NOTE: This function is deprecated in favor of listProjectsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listProjects operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllProjectsResponses(request: requests.ListProjectsRequest): AsyncIterableIterator<responses.ListProjectsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ProjectSummary objects
     * contained in responses from the listProjects operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listProjectsRecordIterator(request: requests.ListProjectsRequest): AsyncIterableIterator<model.ProjectSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listProjects operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listProjectsResponseIterator(request: requests.ListProjectsRequest): AsyncIterableIterator<responses.ListProjectsResponse>;
    /**
     * Returns a list of Schedules.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSchedulesRequest
     * @return ListSchedulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListSchedules.ts.html |here} to see how to use ListSchedules API.
     */
    listSchedules(listSchedulesRequest: requests.ListSchedulesRequest): Promise<responses.ListSchedulesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listSchedulesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ScheduleSummary objects
     * contained in responses from the listSchedules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSchedules(request: requests.ListSchedulesRequest): AsyncIterableIterator<model.ScheduleSummary>;
    /**
     * NOTE: This function is deprecated in favor of listSchedulesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listSchedules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSchedulesResponses(request: requests.ListSchedulesRequest): AsyncIterableIterator<responses.ListSchedulesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ScheduleSummary objects
     * contained in responses from the listSchedules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSchedulesRecordIterator(request: requests.ListSchedulesRequest): AsyncIterableIterator<model.ScheduleSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSchedules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSchedulesResponseIterator(request: requests.ListSchedulesRequest): AsyncIterableIterator<responses.ListSchedulesResponse>;
    /**
     * Lists work request errors for the specified work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsRecordIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsResponseIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Lists work request logs for the specified work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsRecordIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsResponseIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists work requests in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsRecordIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsResponseIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Upload ML Application Package
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PutMlApplicationPackageRequest
     * @return PutMlApplicationPackageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/PutMlApplicationPackage.ts.html |here} to see how to use PutMlApplicationPackage API.
     */
    putMlApplicationPackage(putMlApplicationPackageRequest: requests.PutMlApplicationPackageRequest): Promise<responses.PutMlApplicationPackageResponse>;
    /**
     * Provider can initiate recovery of the resource only if MlApplicationInstanceView is in one of the recoverable sub-states (RECOVERABLE_PROVIDER_ISSUE, RECOVERABLE_SERVICE_ISSUE).
     * Provider should investigate (using MlApplicationInstanceView lifecycleDetails, relevant logs and metrics) and fix the issue before the recovery is initiated.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RecoverMlApplicationInstanceViewRequest
     * @return RecoverMlApplicationInstanceViewResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/RecoverMlApplicationInstanceView.ts.html |here} to see how to use RecoverMlApplicationInstanceView API.
     */
    recoverMlApplicationInstanceView(recoverMlApplicationInstanceViewRequest: requests.RecoverMlApplicationInstanceViewRequest): Promise<responses.RecoverMlApplicationInstanceViewResponse>;
    /**
     * Registers model artifact reference metadata
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RegisterModelArtifactReferenceRequest
     * @return RegisterModelArtifactReferenceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/RegisterModelArtifactReference.ts.html |here} to see how to use RegisterModelArtifactReference API.
     */
    registerModelArtifactReference(registerModelArtifactReferenceRequest: requests.RegisterModelArtifactReferenceRequest): Promise<responses.RegisterModelArtifactReferenceResponse>;
    /**
     * Restore archived model artifact
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RestoreArchivedModelArtifactRequest
     * @return RestoreArchivedModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/RestoreArchivedModelArtifact.ts.html |here} to see how to use RestoreArchivedModelArtifact API.
     */
    restoreArchivedModelArtifact(restoreArchivedModelArtifactRequest: requests.RestoreArchivedModelArtifactRequest): Promise<responses.RestoreArchivedModelArtifactResponse>;
    /**
     * Trigger ML Application Instance flow if possible
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param TriggerMlApplicationInstanceFlowRequest
     * @return TriggerMlApplicationInstanceFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/TriggerMlApplicationInstanceFlow.ts.html |here} to see how to use TriggerMlApplicationInstanceFlow API.
     */
    triggerMlApplicationInstanceFlow(triggerMlApplicationInstanceFlowRequest: requests.TriggerMlApplicationInstanceFlowRequest): Promise<responses.TriggerMlApplicationInstanceFlowResponse>;
    /**
     * Trigger ML Application Instance View flow if possible
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param TriggerMlApplicationInstanceViewFlowRequest
     * @return TriggerMlApplicationInstanceViewFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/TriggerMlApplicationInstanceViewFlow.ts.html |here} to see how to use TriggerMlApplicationInstanceViewFlow API.
     */
    triggerMlApplicationInstanceViewFlow(triggerMlApplicationInstanceViewFlowRequest: requests.TriggerMlApplicationInstanceViewFlowRequest): Promise<responses.TriggerMlApplicationInstanceViewFlowResponse>;
    /**
     * Updates a private endpoint using a `privateEndpointId`.  If changes to a private endpoint match
     * a previously defined private endpoint, then a 409 status code is returned.  This indicates
     * that a conflict has been detected.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataSciencePrivateEndpointRequest
     * @return UpdateDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateDataSciencePrivateEndpoint.ts.html |here} to see how to use UpdateDataSciencePrivateEndpoint API.
     */
    updateDataSciencePrivateEndpoint(updateDataSciencePrivateEndpointRequest: requests.UpdateDataSciencePrivateEndpointRequest): Promise<responses.UpdateDataSciencePrivateEndpointResponse>;
    /**
     * Updates a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJobRequest
     * @return UpdateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateJob.ts.html |here} to see how to use UpdateJob API.
     */
    updateJob(updateJobRequest: requests.UpdateJobRequest): Promise<responses.UpdateJobResponse>;
    /**
     * Updates a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJobRunRequest
     * @return UpdateJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateJobRun.ts.html |here} to see how to use UpdateJobRun API.
     */
    updateJobRun(updateJobRunRequest: requests.UpdateJobRunRequest): Promise<responses.UpdateJobRunResponse>;
    /**
     * Updates the MlApplication
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMlApplicationRequest
     * @return UpdateMlApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateMlApplication.ts.html |here} to see how to use UpdateMlApplication API.
     */
    updateMlApplication(updateMlApplicationRequest: requests.UpdateMlApplicationRequest): Promise<responses.UpdateMlApplicationResponse>;
    /**
     * Updates the MlApplicationImplementation
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMlApplicationImplementationRequest
     * @return UpdateMlApplicationImplementationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateMlApplicationImplementation.ts.html |here} to see how to use UpdateMlApplicationImplementation API.
     */
    updateMlApplicationImplementation(updateMlApplicationImplementationRequest: requests.UpdateMlApplicationImplementationRequest): Promise<responses.UpdateMlApplicationImplementationResponse>;
    /**
     * Updates the MlApplicationImplementationVersion
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMlApplicationImplementationVersionRequest
     * @return UpdateMlApplicationImplementationVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateMlApplicationImplementationVersion.ts.html |here} to see how to use UpdateMlApplicationImplementationVersion API.
     */
    updateMlApplicationImplementationVersion(updateMlApplicationImplementationVersionRequest: requests.UpdateMlApplicationImplementationVersionRequest): Promise<responses.UpdateMlApplicationImplementationVersionResponse>;
    /**
     * Updates the MlApplicationInstance
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMlApplicationInstanceRequest
     * @return UpdateMlApplicationInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateMlApplicationInstance.ts.html |here} to see how to use UpdateMlApplicationInstance API.
     */
    updateMlApplicationInstance(updateMlApplicationInstanceRequest: requests.UpdateMlApplicationInstanceRequest): Promise<responses.UpdateMlApplicationInstanceResponse>;
    /**
     * Updates the MlApplicationInstanceView
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateMlApplicationInstanceViewRequest
     * @return UpdateMlApplicationInstanceViewResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateMlApplicationInstanceView.ts.html |here} to see how to use UpdateMlApplicationInstanceView API.
     */
    updateMlApplicationInstanceView(updateMlApplicationInstanceViewRequest: requests.UpdateMlApplicationInstanceViewRequest): Promise<responses.UpdateMlApplicationInstanceViewResponse>;
    /**
     * Updates the properties of a model. You can update the `displayName`, `description`, `freeformTags`, and `definedTags` properties.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelRequest
     * @return UpdateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateModel.ts.html |here} to see how to use UpdateModel API.
     */
    updateModel(updateModelRequest: requests.UpdateModelRequest): Promise<responses.UpdateModelResponse>;
    /**
     * Updates model custom metadata artifact for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelCustomMetadatumArtifactRequest
     * @return UpdateModelCustomMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateModelCustomMetadatumArtifact.ts.html |here} to see how to use UpdateModelCustomMetadatumArtifact API.
     */
    updateModelCustomMetadatumArtifact(updateModelCustomMetadatumArtifactRequest: requests.UpdateModelCustomMetadatumArtifactRequest): Promise<responses.UpdateModelCustomMetadatumArtifactResponse>;
    /**
     * Updates model defined metadata artifact for specified model metadata key.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelDefinedMetadatumArtifactRequest
     * @return UpdateModelDefinedMetadatumArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateModelDefinedMetadatumArtifact.ts.html |here} to see how to use UpdateModelDefinedMetadatumArtifact API.
     */
    updateModelDefinedMetadatumArtifact(updateModelDefinedMetadatumArtifactRequest: requests.UpdateModelDefinedMetadatumArtifactRequest): Promise<responses.UpdateModelDefinedMetadatumArtifactResponse>;
    /**
     * Updates the properties of a model deployment. Some of the properties of `modelDeploymentConfigurationDetails` or `CategoryLogDetails` can also be updated with zero down time
     * when the model deployment's lifecycle state is ACTIVE or NEEDS_ATTENTION i.e `instanceShapeName`, `instanceCount` and `modelId`, separately `loadBalancerShape` or `CategoryLogDetails`
     * can also be updated independently. All of the fields can be updated when the deployment is in the INACTIVE lifecycle state. Changes will take effect the next time the model
     * deployment is activated.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelDeploymentRequest
     * @return UpdateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateModelDeployment.ts.html |here} to see how to use UpdateModelDeployment API.
     */
    updateModelDeployment(updateModelDeploymentRequest: requests.UpdateModelDeploymentRequest): Promise<responses.UpdateModelDeploymentResponse>;
    /**
     * Updates the provenance information for the specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelProvenanceRequest
     * @return UpdateModelProvenanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateModelProvenance.ts.html |here} to see how to use UpdateModelProvenance API.
     */
    updateModelProvenance(updateModelProvenanceRequest: requests.UpdateModelProvenanceRequest): Promise<responses.UpdateModelProvenanceResponse>;
    /**
     * Updates the properties of a model version set. User can update the `description` property.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelVersionSetRequest
     * @return UpdateModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateModelVersionSet.ts.html |here} to see how to use UpdateModelVersionSet API.
     */
    updateModelVersionSet(updateModelVersionSetRequest: requests.UpdateModelVersionSetRequest): Promise<responses.UpdateModelVersionSetResponse>;
    /**
     * Updates the properties of a notebook session. You can update the `displayName`, `freeformTags`, and `definedTags` properties.
     * When the notebook session is in the INACTIVE lifecycle state, you can update `notebookSessionConfigurationDetails` and change `shape`, `subnetId`, and `blockStorageSizeInGBs`.
     * Changes to the `notebookSessionConfigurationDetails` take effect the next time the `ActivateNotebookSession` action is invoked on the notebook session resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateNotebookSessionRequest
     * @return UpdateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateNotebookSession.ts.html |here} to see how to use UpdateNotebookSession API.
     */
    updateNotebookSession(updateNotebookSessionRequest: requests.UpdateNotebookSessionRequest): Promise<responses.UpdateNotebookSessionResponse>;
    /**
     * Updates the Pipeline.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePipelineRequest
     * @return UpdatePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdatePipeline.ts.html |here} to see how to use UpdatePipeline API.
     */
    updatePipeline(updatePipelineRequest: requests.UpdatePipelineRequest): Promise<responses.UpdatePipelineResponse>;
    /**
     * Updates the PipelineRun.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePipelineRunRequest
     * @return UpdatePipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdatePipelineRun.ts.html |here} to see how to use UpdatePipelineRun API.
     */
    updatePipelineRun(updatePipelineRunRequest: requests.UpdatePipelineRunRequest): Promise<responses.UpdatePipelineRunResponse>;
    /**
     * Updates the properties of a project. You can update the `displayName`, `description`, `freeformTags`, and `definedTags` properties.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
    /**
     * Updates the Schedule
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateScheduleRequest
     * @return UpdateScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/datascience/UpdateSchedule.ts.html |here} to see how to use UpdateSchedule API.
     */
    updateSchedule(updateScheduleRequest: requests.UpdateScheduleRequest): Promise<responses.UpdateScheduleResponse>;
}
export {};
