/**
 * Data Science API
 * Use the Data Science API to organize your data science work, access data and computing resources, and build, train, deploy and manage models and model deployments. For more information, see [Data Science](https://docs.oracle.com/iaas/data-science/using/data-science.htm).

 * OpenAPI spec version: 20190101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Representation of ML Application Instance which providers use for instance observability.
 */
export interface MlApplicationInstanceView {
    /**
     * The OCID of the MlApplicationInstanceView. Unique identifier that is immutable after creation
     */
    "id": string;
    /**
     * The name of the MlApplicationInstance (created by the consumer) which this MlApplicationInstanceView is mirroring.
     */
    "displayName": string;
    /**
     * The OCID of the MlApplicationInstance (created by the consumer) which this MlApplicationInstanceView is mirroring.
     */
    "mlApplicationInstanceId": string;
    /**
     * This field is a copy from MlApplicationInstance created by the consumer. The OCID of ML Application. This resource is an instance of ML Application referenced by this OCID.
     */
    "mlApplicationId": string;
    /**
     * The name of ML Application (based on mlApplicationId).
     */
    "mlApplicationName": string;
    /**
     * This field is a copy from MlApplicationInstance created by the consumer. The OCID of ML Application Implementation selected as a certain solution for a given ML problem (ML Application)
     */
    "mlApplicationImplementationId": string;
    /**
     * This field is a copy from MlApplicationInstance created by the consumer. The name of Ml Application Implemenation (based on mlApplicationImplementationId)
     */
    "mlApplicationImplementationName": string;
    /**
     * Version of MlApplication package which is currently used by this MlApplicationInstance.
     */
    "packageVersion": string;
    /**
     * The OCID of the MlApplicationImplementationVersion
     */
    "mlApplicationImplementationVersionId": string;
    "authConfiguration"?: model.IdcsAuthConfiguration | model.IdcsCustomServiceAuthConfiguration | model.IamAuthConfiguration;
    /**
     * This field is a copy from MlApplicationInstance created by the consumer. Data that are used for provisioning of the given MlApplicationInstance. These are validated against configurationSchema defined in referenced MlApplication.
     */
    "configuration"?: Array<model.ConfigurationProperty>;
    /**
     * This field is a copy from MlApplicationInstance created by the consumer. States whether the MlApplicationInstance is supposed to be in ACTIVE lifecycle state.
     */
    "isEnabled": boolean;
    /**
     * References (Identifiers) for components dedicated to this instance.
     */
    "instanceComponents"?: Array<model.InstanceComponent>;
    /**
     * The OCID of the compartment where the MlApplicationInstanceView is created.
     */
    "compartmentId": string;
    "predictionEndpointDetails"?: model.PredictionEndpointDetails;
    /**
     * The time the the MlApplicationInstanceView was created. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The current state of the MlApplicationInstance(View).
     */
    "lifecycleState": MlApplicationInstanceView.LifecycleState;
    /**
     * The current substate of the MlApplicationInstance(View). The substate has MlApplicationInstance(View) specific values in comparison with lifecycleState which has standard values common for all OCI resources.
     * The NEEDS_ATTENTION and FAILED substates are deprecated in favor of (NON_)?RECOVERABLE_(PROVIDER|SERVICE)_ISSUE and will be removed in next release.
     *
     */
    "lifecycleSubstate": MlApplicationInstanceView.LifecycleSubstate;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails": string;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](https://docs.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace MlApplicationInstanceView {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        NeedsAttention = "NEEDS_ATTENTION",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleSubstate {
        Creating = "CREATING",
        Updating = "UPDATING",
        Upgrading = "UPGRADING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        NeedsAttention = "NEEDS_ATTENTION",
        Failed = "FAILED",
        NonRecoverableProviderIssue = "NON_RECOVERABLE_PROVIDER_ISSUE",
        RecoverableProviderIssue = "RECOVERABLE_PROVIDER_ISSUE",
        NonRecoverableServiceIssue = "NON_RECOVERABLE_SERVICE_ISSUE",
        RecoverableServiceIssue = "RECOVERABLE_SERVICE_ISSUE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: MlApplicationInstanceView): object;
    function getDeserializedJsonObj(obj: MlApplicationInstanceView): object;
}
