/**
 * Oracle Delegate Access Control API
 * Oracle Delegate Access Control allows ExaCC and ExaCS customers to delegate management of their Exadata resources operators outside their tenancies.
With Delegate Access Control, Support Providers can deliver managed services using comprehensive and robust tooling built on the OCI platform.
Customers maintain control over who has access to the delegated resources in their tenancy and what actions can be taken.
Enterprises managing resources across multiple tenants can use Delegate Access Control to streamline management tasks.
Using logging service, customers can view a near real-time audit report of all actions performed by a Service Provider operator.

 * OpenAPI spec version: 20230801
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as serviceRequests from "./request";
import * as serviceResponses from "./response";
import * as models from "./model";
import { DelegateAccessControlClient } from "./client";
export declare class DelegateAccessControlWaiter {
    private client;
    private readonly config?;
    constructor(client: DelegateAccessControlClient, config?: Partial<import("oci-common/lib/waiter").WaiterConfigurationDetails> | undefined);
    /**
     * Waits forDelegatedResourceAccessRequest till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetDelegatedResourceAccessRequestResponse
     */
    forDelegatedResourceAccessRequest(request: serviceRequests.GetDelegatedResourceAccessRequestRequest, ...targetStates: models.DelegatedResourceAccessRequest.LifecycleState[]): Promise<serviceResponses.GetDelegatedResourceAccessRequestResponse>;
    /**
     * Waits forDelegationControl till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetDelegationControlResponse | null (null in case of 404 response)
     */
    forDelegationControl(request: serviceRequests.GetDelegationControlRequest, ...targetStates: models.DelegationControl.LifecycleState[]): Promise<serviceResponses.GetDelegationControlResponse | null>;
    /**
     * Waits forDelegationSubscription till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetDelegationSubscriptionResponse | null (null in case of 404 response)
     */
    forDelegationSubscription(request: serviceRequests.GetDelegationSubscriptionRequest, ...targetStates: models.DelegationSubscription.LifecycleState[]): Promise<serviceResponses.GetDelegationSubscriptionResponse | null>;
    /**
     * Waits forServiceProvider till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetServiceProviderResponse | null (null in case of 404 response)
     */
    forServiceProvider(request: serviceRequests.GetServiceProviderRequest, ...targetStates: models.ServiceProvider.LifecycleState[]): Promise<serviceResponses.GetServiceProviderResponse | null>;
    /**
     * Waits forServiceProviderAction till it reaches any of the provided states
     *
     * @param request the request to send
     * @param targetStates the desired states to wait for. The waiter will return once the resource reaches any of the provided states
     * @return response returns GetServiceProviderActionResponse
     */
    forServiceProviderAction(request: serviceRequests.GetServiceProviderActionRequest, ...targetStates: models.ServiceProviderAction.LifecycleState[]): Promise<serviceResponses.GetServiceProviderActionResponse>;
}
