/**
 * Globally Distributed Database
 * Use the Globally Distributed Database service APIs to create and manage the Globally distributed databases.
 * OpenAPI spec version: 20250101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Details required for creation of the Globally distributed database.
 */
export interface CreateDistributedDatabaseDetails {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Globally distributed database compartment.
     */
    "compartmentId": string;
    /**
     * The display name of the Globally distributed database.
     */
    "displayName": string;
    /**
     * Oracle Database version for the shards and catalog used in Globally distributed database.
     */
    "databaseVersion": string;
    /**
     * Unique name prefix for the Globally distributed databases. Only alpha-numeric values are allowed. First character
     * has to be a letter followed by any combination of letter and number.
     *
     */
    "prefix": string;
    /**
     * The collection of [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint associated with Globally distributed autonomous database.
     */
    "privateEndpointIds": Array<string>;
    /**
     * Sharding Methods for the Globally distributed database.
     */
    "shardingMethod": CreateDistributedDatabaseDetails.ShardingMethod;
    /**
     * The character set for the database.
     */
    "characterSet": string;
    /**
     * The national character set for the database.
     */
    "ncharacterSet": string;
    /**
     * The default number of unique chunks in a shardspace. The value of chunks must be
     * greater than 2 times the size of the largest shardgroup in any shardspace.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "chunks"?: number;
    /**
     * The listener port number for the Globally distributed database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "listenerPort": number;
    /**
     * The TLS listener port number for Globally distributed database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "listenerPortTls"?: number;
    /**
     * Ons local port number. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "onsPortLocal": number;
    /**
     * Ons remote port number. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "onsPortRemote": number;
    /**
     * The Replication method for Globally distributed database. Use RAFT for Raft replication, and DG for
     * DataGuard. If replicationMethod is not provided, it defaults to DG.
     *
     */
    "replicationMethod"?: CreateDistributedDatabaseDetails.ReplicationMethod;
    /**
     * The Replication factor for RAFT replication based Globally distributed database. Currently supported values are 3, 5 and 7.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "replicationFactor"?: number;
    /**
     * For RAFT replication based Globally distributed database, the value should be atleast twice the number of shards. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "replicationUnit"?: number;
    /**
     * The distributed database deployment type.
     *
     */
    "dbDeploymentType": CreateDistributedDatabaseDetails.DbDeploymentType;
    /**
     * Collection of shards for the Globally distributed database.
     */
    "shardDetails": Array<model.CreateDistributedDatabaseShardDetails>;
    /**
     * Collection of catalog for the Globally distributed database.
     */
    "catalogDetails": Array<model.CreateDistributedDatabaseCatalogDetails>;
    /**
     * The SSH public key for Global service manager instances.
     */
    "gsmSshPublicKey"?: string;
    "dbBackupConfig"?: model.DistributedDbBackupConfig;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateDistributedDatabaseDetails {
    enum ShardingMethod {
        User = "USER",
        System = "SYSTEM"
    }
    enum ReplicationMethod {
        Raft = "RAFT",
        Dg = "DG"
    }
    enum DbDeploymentType {
        ExadbXs = "EXADB_XS"
    }
    function getJsonObj(obj: CreateDistributedDatabaseDetails): object;
    function getDeserializedJsonObj(obj: CreateDistributedDatabaseDetails): object;
}
