/**
 * Globally Distributed Database
 * Use the Globally Distributed Database service APIs to create and manage the Globally distributed databases.
 * OpenAPI spec version: 20250101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Globally distributed autonomous database.
 */
export interface DistributedAutonomousDatabaseSummary {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Globally distributed autonomous database.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Globally distributed autonomous database compartment.
     */
    "compartmentId": string;
    /**
     * The display name of the Globally distributed autonomous database.
     */
    "displayName": string;
    /**
     * The time the Globally distributed autonomous database was created. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The time the Globally distributed autonomous database was last updated. An RFC3339 formatted datetime string
     */
    "timeUpdated": Date;
    /**
     * Oracle Database version for the shards and catalog used in Globally distributed autonomous database.
     */
    "databaseVersion": string;
    /**
     * Lifecycle state of sharded database.
     */
    "lifecycleState": string;
    /**
     * The lifecycleDetails for the Globally distributed autonomous database.
     */
    "lifecycleDetails": string;
    "connectionStrings"?: model.DistributedAutonomousDatabaseConnectionString;
    /**
     * Unique name prefix for the Globally distributed autonomous databases. Only alpha-numeric values are allowed. First character
     * has to be a letter followed by any combination of letter and number.
     *
     */
    "prefix": string;
    /**
     * The collection of [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private endpoint associated with Globally distributed autonomous database.
     */
    "privateEndpointIds": Array<string>;
    /**
     * Sharding Methods for the Globally distributed autonomous database.
     */
    "shardingMethod": string;
    /**
     * The workload type for the database.
     */
    "dbWorkload": string;
    /**
     * The character set for the database.
     */
    "characterSet": string;
    /**
     * The national character set for the database.
     */
    "ncharacterSet": string;
    /**
     * The default number of unique chunks in a shardspace. The value of chunks must be
     * greater than 2 times the size of the largest shardgroup in any shardspace.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "chunks"?: number;
    /**
     * The listener port number for the Globally distributed autonomous database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "listenerPort": number;
    /**
     * The TLS listener port number for the Globally distributed autonomous database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "listenerPortTls"?: number;
    /**
     * Ons local port number for the Globally distributed autonomous database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "onsPortLocal": number;
    /**
     * Ons remote port number for the Globally distributed autonomous database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "onsPortRemote": number;
    /**
     * The Replication method for Globally distributed autonomous database. Use RAFT for Raft replication, and DG for
     * DataGuard. If replicationMethod is not provided, it defaults to DG.
     *
     */
    "replicationMethod"?: string;
    /**
     * The Replication factor for RAFT replication based Globally distributed autonomous database. Currently supported values are 3, 5 and 7.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "replicationFactor"?: number;
    /**
     * For RAFT replication based Globally distributed autonomous database, the value should be atleast twice the number of shards. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "replicationUnit"?: number;
    /**
     * The distributed autonomous database deployment type.
     *
     */
    "dbDeploymentType": DistributedAutonomousDatabaseSummary.DbDeploymentType;
    "metadata"?: model.DistributedAutonomousDbMetadata;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace DistributedAutonomousDatabaseSummary {
    enum DbDeploymentType {
        AdbD = "ADB_D",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: DistributedAutonomousDatabaseSummary): object;
    function getDeserializedJsonObj(obj: DistributedAutonomousDatabaseSummary): object;
}
