/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20250228
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary information about a CatalogItem.
 */
export interface CatalogItemSummary {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the catalog.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * Config source type Eg: STACK_TEMPLATE_CATALOG_SOURCE, PAR_CATALOG_SOURCE, GIT_CATALOG_SOURCE, MARKETPLACE_CATALOG_SOURCE.
     *
     */
    "configSourceType": string;
    /**
     * The description of the catalogItem.
     */
    "description": string;
    "catalogSourcePayload"?: model.CatalogGitSourceConfig | model.CatalogSourceTemplateConfig | model.CatalogParSourceConfig | model.CatalogMarketplaceSourceConfig;
    "catalogResultPayload"?: model.CatalogGitResultConfig | model.CatalogTemplateResultConfig | model.CatalogParResultConfig;
    /**
     * The catalog listing Id.
     *
     */
    "listingId": string;
    /**
     * The catalog package version.
     *
     */
    "listingVersion": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
     */
    "displayName": string;
    /**
     * Config package type Eg: BASE_PACKAGE, EXTENSION_PACKAGE.
     *
     */
    "packageType": string;
    /**
     * The current state of the CatalogItem.
     */
    "lifecycleState": string;
    /**
     * The details of lifecycle state CatalogItem.
     */
    "lifecycleDetails": string;
    /**
     * The date and time the CatalogItem was created, in the format defined by
     * [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2016-08-25T21:10:29.600Z}
     *
     */
    "timeCreated": Date;
    /**
     * The date and time the CatalogItem was updated, in the format defined by
     * [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2016-08-25T21:10:29.600Z}
     *
     */
    "timeUpdated": Date;
    /**
     * Version description about the catalog item.
     */
    "versionDescription": string;
    /**
     * Short description about the catalog item.
     */
    "shortDescription": string;
    /**
     * The date and time the CatalogItem was released, in the format defined by
     * [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2016-08-25T21:10:29.600Z}
     *
     */
    "timeReleased": Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CatalogItemSummary {
    function getJsonObj(obj: CatalogItemSummary): object;
    function getDeserializedJsonObj(obj: CatalogItemSummary): object;
}
