/**
 * Fleet Application Management Service API
 * Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.

 * OpenAPI spec version: 20250228
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
* A FamProvision is a description of a FamProvision.
* <p>
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to
* an administrator. If you're an administrator who needs to write policies to give users access, see
* [Getting Started with Policies](https://docs.oracle.com/iaas/Content/Identity/policiesgs/get-started-with-policies.htm).
*
*/
export interface Provision {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the FamProvision.
     */
    "id": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     */
    "displayName": string;
    /**
     * A description of the provision.
     */
    "provisionDescription"?: string;
    /**
     * A mandatory variable added to a list of RMS variables for createStack API. Overrides the one supplied in configuration file.
     */
    "tfVariableTenancyId": string;
    /**
     * A mandatory variable added to a list of RMS variables for createStack API. Overrides the one supplied in configuration file.
     */
    "tfVariableRegionId": string;
    /**
     * An optional variable added to a list of RMS variables for createStack API. Overrides the one supplied in configuration file.
     */
    "tfVariableCurrentUserId"?: string;
    /**
     * An optional variable added to a list of RMS variables for createStack API. Overrides the one supplied in configuration file.
     */
    "tfVariableCompartmentId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
      * The date and time the FamProvision was created, in the format defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
      * The date and time the FamProvision was updated, in the format defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeUpdated"?: Date;
    /**
     * The current state of the FamProvision.
     */
    "lifecycleState": Provision.LifecycleState;
    /**
     * A message that describes the current state of the FamProvision in more detail. For example,
     * can be used to provide actionable information for a resource in the Failed state.
     *
     */
    "lifecycleDetails"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Catalog Item.
     */
    "packageCatalogItemId": string;
    /**
     * A [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Catalog Item to a file with key/value pairs to set up variables for createStack API.
     */
    "configCatalogItemId": string;
    /**
     * A display Name of the Catalog Item in the Catalog.
     */
    "packageCatalogItemDisplayName": string;
    /**
     * A listing ID of the Catalog Item in the Catalog.
     */
    "packageCatalogItemListingId": string;
    /**
     * A listing version of the Catalog Item in the Catalog.
     */
    "packageCatalogItemListingVersion": string;
    /**
     * A display Name of the Catalog Item in the Catalog.
     */
    "configCatalogItemDisplayName": string;
    /**
     * A listing ID of the Catalog Item in the Catalog.
     */
    "configCatalogItemListingId": string;
    /**
     * A listing version of the Catalog Item in the Catalog.
     */
    "configCatalogItemListingVersion": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the RMS Stack.
     */
    "stackId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
     */
    "fleetId": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the RMS APPLY Job.
     */
    "rmsApplyJobId"?: string;
    /**
     * Outputs from the Terraform Apply job
     */
    "tfOutputs"?: Array<model.JobExecutionDetails>;
    /**
     * The deployed resources and their summary
     */
    "deployedResources"?: Array<model.DeployedResourceDetails>;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace Provision {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Provision): object;
    function getDeserializedJsonObj(obj: Provision): object;
}
