/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information about a new DB2 Connection.
 *
 */
export interface CreateDb2ConnectionDetails extends model.CreateConnectionDetails {
    /**
     * The DB2 technology type.
     */
    "technologyType": string;
    /**
     * The name of the database.
     *
     */
    "databaseName": string;
    /**
     * The name or address of a host.
     *
     */
    "host": string;
    /**
     * The port of an endpoint usually specified for a connection.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "port": number;
    /**
     * The username Oracle GoldenGate uses to connect to the DB2 database.
     * This username must already exist and be available by the DB2 to be connected to.
     *
     */
    "username": string;
    /**
     * The password Oracle GoldenGate uses to connect the associated DB2 database.
     * Deprecated: This field is deprecated and replaced by \"passwordSecretId\". This field will be removed after February 15 2026.
     *
     */
    "password"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret where the password is stored,
     * that Oracle GoldenGate uses to connect the associated DB2 database.
     * Note: When provided, 'password' field must not be provided.
     *
     */
    "passwordSecretId"?: string;
    /**
     * An array of name-value pair attribute entries.
     * Used as additional parameters in connection string.
     *
     */
    "additionalAttributes"?: Array<model.NameValuePair>;
    /**
     * Security protocol for the DB2 database.
     */
    "securityProtocol": string;
    /**
     * The base64 encoded keystore file created at the client containing the server certificate / CA root certificate.
     * Deprecated: This field is deprecated and replaced by \"sslClientKeystoredbSecretId\". This field will be removed after February 15 2026.
     *
     */
    "sslClientKeystoredb"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret where the keystore file stored,
     * which created at the client containing the server certificate / CA root certificate.
     * Note: When provided, 'sslClientKeystoredb' field must not be provided.
     *
     */
    "sslClientKeystoredbSecretId"?: string;
    /**
     * The base64 encoded keystash file which contains the encrypted password to the key database file.
     * Deprecated: This field is deprecated and replaced by \"sslClientKeystashSecretId\". This field will be removed after February 15 2026.
     *
     */
    "sslClientKeystash"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret where the keystash file is stored,
     * which contains the encrypted password to the key database file.
     * Note: When provided, 'sslClientKeystash' field must not be provided.
     *
     */
    "sslClientKeystashSecretId"?: string;
    /**
     * The base64 encoded file which contains the self-signed server certificate / Certificate Authority (CA) certificate.
     * It is not included in GET responses if the {@code view=COMPACT} query parameter is specified.
     *
     */
    "sslServerCertificate"?: string;
    "connectionType": string;
}
export declare namespace CreateDb2ConnectionDetails {
    function getJsonObj(obj: CreateDb2ConnectionDetails, isParentJsonObj?: boolean): object;
    const connectionType = "DB2";
    function getDeserializedJsonObj(obj: CreateDb2ConnectionDetails, isParentJsonObj?: boolean): object;
}
