/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Represents the metadata of a MongoDB Connection.
 *
 */
export interface MongoDbConnection extends model.Connection {
    /**
     * The MongoDB technology type.
     */
    "technologyType": MongoDbConnection.TechnologyType;
    /**
     * MongoDB connection string.
     * e.g.: 'mongodb://mongodb0.example.com:27017/recordsrecords'
     *
     */
    "connectionString"?: string;
    /**
     * The username Oracle GoldenGate uses to connect to the database.
     * This username must already exist and be available by the database to be connected to.
     *
     */
    "username"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Oracle Autonomous Json Database.
     *
     */
    "databaseId"?: string;
    /**
     * Security Protocol for MongoDB.
     */
    "securityProtocol"?: MongoDbConnection.SecurityProtocol;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret that stores the password Oracle GoldenGate uses to connect the associated database.
     * Note: When provided, 'password' field must not be provided.
     *
     */
    "passwordSecretId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret that stores the certificate key file of the mtls connection.
     * - The content of a .pem file containing the client private key (for 2-way SSL).
     * Note: When provided, 'tlsCertificateKeyFile' field must not be provided.
     *
     */
    "tlsCertificateKeyFileSecretId"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Secret that stores the password of the tls certificate key file.
     * Note: When provided, 'tlsCertificateKeyFilePassword' field must not be provided.
     *
     */
    "tlsCertificateKeyFilePasswordSecretId"?: string;
    /**
     * Database Certificate - The base64 encoded content of a .pem file, containing the server public key (for 1 and 2-way SSL).
     * It is not included in GET responses if the {@code view=COMPACT} query parameter is specified.
     *
     */
    "tlsCaFile"?: string;
    "connectionType": string;
}
export declare namespace MongoDbConnection {
    enum TechnologyType {
        Mongodb = "MONGODB",
        OciAutonomousJsonDatabase = "OCI_AUTONOMOUS_JSON_DATABASE",
        AzureCosmosDbForMongodb = "AZURE_COSMOS_DB_FOR_MONGODB",
        AmazonDocumentDb = "AMAZON_DOCUMENT_DB",
        OracleJsonCollection = "ORACLE_JSON_COLLECTION",
        OracleRestDataServices = "ORACLE_REST_DATA_SERVICES",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SecurityProtocol {
        Plain = "PLAIN",
        Tls = "TLS",
        Mtls = "MTLS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: MongoDbConnection, isParentJsonObj?: boolean): object;
    const connectionType = "MONGODB";
    function getDeserializedJsonObj(obj: MongoDbConnection, isParentJsonObj?: boolean): object;
}
