/**
 * Java Management Service Fleets API
 * The APIs for the [Fleet Management](https://docs.oracle.com/en-us/iaas/jms/doc/fleet-management.html) feature of Java Management Service to monitor and manage the usage of Java in your enterprise. Use these APIs to manage fleets, configure managed instances to report to fleets, and gain insights into the Java workloads running on these instances by carrying out basic and advanced features.
 * OpenAPI spec version: 20210610
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { JavaManagementServiceWaiter } from "./javamanagementservice-waiter";
declare const Breaker: any;
export declare enum JavaManagementServiceApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class JavaManagementServiceClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": JavaManagementServiceWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    protected _authProvider: common.AuthenticationDetailsProvider | undefined;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new JavaManagementServiceWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): JavaManagementServiceWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): JavaManagementServiceWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the provider if possible which in turn shuts down any associated circuit breaker
     */
    closeProvider(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Add Java installation sites in a Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddFleetInstallationSitesRequest
     * @return AddFleetInstallationSitesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/AddFleetInstallationSites.ts.html |here} to see how to use AddFleetInstallationSites API.
     */
    addFleetInstallationSites(addFleetInstallationSitesRequest: requests.AddFleetInstallationSitesRequest): Promise<responses.AddFleetInstallationSitesResponse>;
    /**
     * Deletes the work request specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Move a specified Fleet into the compartment identified in the POST form. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFleetCompartmentRequest
     * @return ChangeFleetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ChangeFleetCompartment.ts.html |here} to see how to use ChangeFleetCompartment API.
     */
    changeFleetCompartment(changeFleetCompartmentRequest: requests.ChangeFleetCompartmentRequest): Promise<responses.ChangeFleetCompartmentResponse>;
    /**
     * Add a new record to the fleet blocklist.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateBlocklistRequest
     * @return CreateBlocklistResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/CreateBlocklist.ts.html |here} to see how to use CreateBlocklist API.
     */
    createBlocklist(createBlocklistRequest: requests.CreateBlocklistRequest): Promise<responses.CreateBlocklistResponse>;
    /**
     * Request to perform validation of the DRS file and create the file to the Object Storage.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDrsFileRequest
     * @return CreateDrsFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/CreateDrsFile.ts.html |here} to see how to use CreateDrsFile API.
     */
    createDrsFile(createDrsFileRequest: requests.CreateDrsFileRequest): Promise<responses.CreateDrsFileResponse>;
    /**
       * Create a new Fleet using the information provided.
  * <p>
  `inventoryLog` is now a required parameter for CreateFleet API.
  * Update existing applications using this API
  * before July 15, 2022 to ensure the applications continue to work.
  * See the [Service Change Notice](https://docs.oracle.com/en-us/iaas/Content/servicechanges.htm#JMS) for more details.
  * Migrate existing fleets using the `UpdateFleet` API to set the `inventoryLog` parameter.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateFleetRequest
       * @return CreateFleetResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/CreateFleet.ts.html |here} to see how to use CreateFleet API.
       */
    createFleet(createFleetRequest: requests.CreateFleetRequest): Promise<responses.CreateFleetResponse>;
    /**
     * Registers an agent's JmsPlugin, optionally attaching to an existing fleet of the tenancy.
     * JmsPlugins registered fleet-less are created with lifecycle state INACTIVE.
     * For the operation to be authorized, the agent must exist, and the authorized user requires JMS_PLUGIN_CREATE permission for the agent's compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJmsPluginRequest
     * @return CreateJmsPluginResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/CreateJmsPlugin.ts.html |here} to see how to use CreateJmsPlugin API.
     */
    createJmsPlugin(createJmsPluginRequest: requests.CreateJmsPluginRequest): Promise<responses.CreateJmsPluginResponse>;
    /**
     * Deletes the blocklist record specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteBlocklistRequest
     * @return DeleteBlocklistResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeleteBlocklist.ts.html |here} to see how to use DeleteBlocklist API.
     */
    deleteBlocklist(deleteBlocklistRequest: requests.DeleteBlocklistRequest): Promise<responses.DeleteBlocklistResponse>;
    /**
     * Deletes the metadata for the result of a Crypto event analysis. The actual report shall remain in the object storage.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCryptoAnalysisResultRequest
     * @return DeleteCryptoAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeleteCryptoAnalysisResult.ts.html |here} to see how to use DeleteCryptoAnalysisResult API.
     */
    deleteCryptoAnalysisResult(deleteCryptoAnalysisResultRequest: requests.DeleteCryptoAnalysisResultRequest): Promise<responses.DeleteCryptoAnalysisResultResponse>;
    /**
     * Request to delete the DRS file from the Object Storage.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDrsFileRequest
     * @return DeleteDrsFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeleteDrsFile.ts.html |here} to see how to use DeleteDrsFile API.
     */
    deleteDrsFile(deleteDrsFileRequest: requests.DeleteDrsFileRequest): Promise<responses.DeleteDrsFileResponse>;
    /**
     * Deletes the Fleet specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFleetRequest
     * @return DeleteFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeleteFleet.ts.html |here} to see how to use DeleteFleet API.
     */
    deleteFleet(deleteFleetRequest: requests.DeleteFleetRequest): Promise<responses.DeleteFleetResponse>;
    /**
     * Delete the Java migration analysis result. The actual report will remain in the Object Storage bucket.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJavaMigrationAnalysisResultRequest
     * @return DeleteJavaMigrationAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeleteJavaMigrationAnalysisResult.ts.html |here} to see how to use DeleteJavaMigrationAnalysisResult API.
     */
    deleteJavaMigrationAnalysisResult(deleteJavaMigrationAnalysisResultRequest: requests.DeleteJavaMigrationAnalysisResultRequest): Promise<responses.DeleteJavaMigrationAnalysisResultResponse>;
    /**
     * Deletes a JmsPlugin. The JmsPlugin may be visible for some time with state DELETED.
     * Deleted plugins will not be able to communicate with the JMS service.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJmsPluginRequest
     * @return DeleteJmsPluginResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeleteJmsPlugin.ts.html |here} to see how to use DeleteJmsPlugin API.
     */
    deleteJmsPlugin(deleteJmsPluginRequest: requests.DeleteJmsPluginRequest): Promise<responses.DeleteJmsPluginResponse>;
    /**
     * Deletes only the metadata of the Performance Tuning Analysis result, but the file remains in the object storage.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeletePerformanceTuningAnalysisResultRequest
     * @return DeletePerformanceTuningAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DeletePerformanceTuningAnalysisResult.ts.html |here} to see how to use DeletePerformanceTuningAnalysisResult API.
     */
    deletePerformanceTuningAnalysisResult(deletePerformanceTuningAnalysisResultRequest: requests.DeletePerformanceTuningAnalysisResultRequest): Promise<responses.DeletePerformanceTuningAnalysisResultResponse>;
    /**
     * Request to disable the DRS in the selected target in the Fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableDrsRequest
     * @return DisableDrsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/DisableDrs.ts.html |here} to see how to use DisableDrs API.
     */
    disableDrs(disableDrsRequest: requests.DisableDrsRequest): Promise<responses.DisableDrsResponse>;
    /**
     * Request to enable the DRS in the selected target in the Fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableDrsRequest
     * @return EnableDrsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/EnableDrs.ts.html |here} to see how to use EnableDrs API.
     */
    enableDrs(enableDrsRequest: requests.EnableDrsRequest): Promise<responses.EnableDrsResponse>;
    /**
     * Generates Agent Deploy Script for Fleet using the information provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateAgentDeployScriptRequest
     * @return GenerateAgentDeployScriptResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GenerateAgentDeployScript.ts.html |here} to see how to use GenerateAgentDeployScript API.
     */
    generateAgentDeployScript(generateAgentDeployScriptRequest: requests.GenerateAgentDeployScriptRequest): Promise<responses.GenerateAgentDeployScriptResponse>;
    /**
     * Generates the agent installer configuration using the information provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateAgentInstallerConfigurationRequest
     * @return GenerateAgentInstallerConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GenerateAgentInstallerConfiguration.ts.html |here} to see how to use GenerateAgentInstallerConfiguration API.
     */
    generateAgentInstallerConfiguration(generateAgentInstallerConfigurationRequest: requests.GenerateAgentInstallerConfigurationRequest): Promise<responses.GenerateAgentInstallerConfigurationResponse>;
    /**
     * Generates Load Pipeline Script
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateLoadPipelineScriptRequest
     * @return GenerateLoadPipelineScriptResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GenerateLoadPipelineScript.ts.html |here} to see how to use GenerateLoadPipelineScript API.
     */
    generateLoadPipelineScript(generateLoadPipelineScriptRequest: requests.GenerateLoadPipelineScriptRequest): Promise<responses.GenerateLoadPipelineScriptResponse>;
    /**
     * Retrieve the metadata for the result of a Crypto event analysis.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCryptoAnalysisResultRequest
     * @return GetCryptoAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetCryptoAnalysisResult.ts.html |here} to see how to use GetCryptoAnalysisResult API.
     */
    getCryptoAnalysisResult(getCryptoAnalysisResultRequest: requests.GetCryptoAnalysisResultRequest): Promise<responses.GetCryptoAnalysisResultResponse>;
    /**
     * Get the detail about the created DRS file in the Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDrsFileRequest
     * @return GetDrsFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetDrsFile.ts.html |here} to see how to use GetDrsFile API.
     */
    getDrsFile(getDrsFileRequest: requests.GetDrsFileRequest): Promise<responses.GetDrsFileResponse>;
    /**
     * Returns export setting for the specified fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetExportSettingRequest
     * @return GetExportSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetExportSetting.ts.html |here} to see how to use GetExportSetting API.
     */
    getExportSetting(getExportSettingRequest: requests.GetExportSettingRequest): Promise<responses.GetExportSettingResponse>;
    /**
     * Returns last export status for the specified fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetExportStatusRequest
     * @return GetExportStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetExportStatus.ts.html |here} to see how to use GetExportStatus API.
     */
    getExportStatus(getExportStatusRequest: requests.GetExportStatusRequest): Promise<responses.GetExportStatusResponse>;
    /**
     * Retrieve a Fleet with the specified identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetRequest
     * @return GetFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetFleet.ts.html |here} to see how to use GetFleet API.
     */
    getFleet(getFleetRequest: requests.GetFleetRequest): Promise<responses.GetFleetResponse>;
    /**
     * Returns Fleet level advanced feature configuration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetAdvancedFeatureConfigurationRequest
     * @return GetFleetAdvancedFeatureConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetFleetAdvancedFeatureConfiguration.ts.html |here} to see how to use GetFleetAdvancedFeatureConfiguration API.
     */
    getFleetAdvancedFeatureConfiguration(getFleetAdvancedFeatureConfigurationRequest: requests.GetFleetAdvancedFeatureConfigurationRequest): Promise<responses.GetFleetAdvancedFeatureConfigurationResponse>;
    /**
     * Retrieve a Fleet Agent Configuration for the specified Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFleetAgentConfigurationRequest
     * @return GetFleetAgentConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetFleetAgentConfiguration.ts.html |here} to see how to use GetFleetAgentConfiguration API.
     */
    getFleetAgentConfiguration(getFleetAgentConfigurationRequest: requests.GetFleetAgentConfigurationRequest): Promise<responses.GetFleetAgentConfigurationResponse>;
    /**
     * Returns metadata associated with a specific Java release family.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaFamilyRequest
     * @return GetJavaFamilyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetJavaFamily.ts.html |here} to see how to use GetJavaFamily API.
     */
    getJavaFamily(getJavaFamilyRequest: requests.GetJavaFamilyRequest): Promise<responses.GetJavaFamilyResponse>;
    /**
     * Retrieve Java Migration Analysis result.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaMigrationAnalysisResultRequest
     * @return GetJavaMigrationAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetJavaMigrationAnalysisResult.ts.html |here} to see how to use GetJavaMigrationAnalysisResult API.
     */
    getJavaMigrationAnalysisResult(getJavaMigrationAnalysisResultRequest: requests.GetJavaMigrationAnalysisResultRequest): Promise<responses.GetJavaMigrationAnalysisResultResponse>;
    /**
     * Returns detail of a Java release.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaReleaseRequest
     * @return GetJavaReleaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetJavaRelease.ts.html |here} to see how to use GetJavaRelease API.
     */
    getJavaRelease(getJavaReleaseRequest: requests.GetJavaReleaseRequest): Promise<responses.GetJavaReleaseResponse>;
    /**
     * Returns the JmsPlugin.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJmsPluginRequest
     * @return GetJmsPluginResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetJmsPlugin.ts.html |here} to see how to use GetJmsPlugin API.
     */
    getJmsPlugin(getJmsPluginRequest: requests.GetJmsPluginRequest): Promise<responses.GetJmsPluginResponse>;
    /**
     * Retrieve metadata of the Performance Tuning Analysis result.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPerformanceTuningAnalysisResultRequest
     * @return GetPerformanceTuningAnalysisResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetPerformanceTuningAnalysisResult.ts.html |here} to see how to use GetPerformanceTuningAnalysisResult API.
     */
    getPerformanceTuningAnalysisResult(getPerformanceTuningAnalysisResultRequest: requests.GetPerformanceTuningAnalysisResultRequest): Promise<responses.GetPerformanceTuningAnalysisResultResponse>;
    /**
     * Retrieve the details of a work request with the specified ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of the agent installer information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAgentInstallersRequest
     * @return ListAgentInstallersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListAgentInstallers.ts.html |here} to see how to use ListAgentInstallers API.
     */
    listAgentInstallers(listAgentInstallersRequest: requests.ListAgentInstallersRequest): Promise<responses.ListAgentInstallersResponse>;
    /**
     * Return a list of AnnouncementSummary items
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAnnouncementsRequest
     * @return ListAnnouncementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListAnnouncements.ts.html |here} to see how to use ListAnnouncements API.
     */
    listAnnouncements(listAnnouncementsRequest: requests.ListAnnouncementsRequest): Promise<responses.ListAnnouncementsResponse>;
    /**
     * Returns a list of blocklist entities contained by a fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListBlocklistsRequest
     * @return ListBlocklistsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListBlocklists.ts.html |here} to see how to use ListBlocklists API.
     */
    listBlocklists(listBlocklistsRequest: requests.ListBlocklistsRequest): Promise<responses.ListBlocklistsResponse>;
    /**
     * Lists the results of a Crypto event analysis.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCryptoAnalysisResultsRequest
     * @return ListCryptoAnalysisResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListCryptoAnalysisResults.ts.html |here} to see how to use ListCryptoAnalysisResults API.
     */
    listCryptoAnalysisResults(listCryptoAnalysisResultsRequest: requests.ListCryptoAnalysisResultsRequest): Promise<responses.ListCryptoAnalysisResultsResponse>;
    /**
     * List the details about the created DRS files in the Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDrsFilesRequest
     * @return ListDrsFilesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListDrsFiles.ts.html |here} to see how to use ListDrsFiles API.
     */
    listDrsFiles(listDrsFilesRequest: requests.ListDrsFilesRequest): Promise<responses.ListDrsFilesResponse>;
    /**
     * List potential diagnoses that would put a fleet into FAILED or NEEDS_ATTENTION lifecycle state.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetDiagnosesRequest
     * @return ListFleetDiagnosesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListFleetDiagnoses.ts.html |here} to see how to use ListFleetDiagnoses API.
     */
    listFleetDiagnoses(listFleetDiagnosesRequest: requests.ListFleetDiagnosesRequest): Promise<responses.ListFleetDiagnosesResponse>;
    /**
     * Returns a list of fleet errors that describe all detected errors.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetErrorsRequest
     * @return ListFleetErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListFleetErrors.ts.html |here} to see how to use ListFleetErrors API.
     */
    listFleetErrors(listFleetErrorsRequest: requests.ListFleetErrorsRequest): Promise<responses.ListFleetErrorsResponse>;
    /**
     * Returns a list of all the Fleets contained by a compartment. The query parameter `compartmentId`
     * is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFleetsRequest
     * @return ListFleetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListFleets.ts.html |here} to see how to use ListFleets API.
     */
    listFleets(listFleetsRequest: requests.ListFleetsRequest): Promise<responses.ListFleetsResponse>;
    /**
     * List Java installation sites in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInstallationSitesRequest
     * @return ListInstallationSitesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListInstallationSites.ts.html |here} to see how to use ListInstallationSites API.
     */
    listInstallationSites(listInstallationSitesRequest: requests.ListInstallationSitesRequest): Promise<responses.ListInstallationSitesResponse>;
    /**
     * Returns a list of the Java release family information.
     * A Java release family is typically a major version in the Java version identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaFamiliesRequest
     * @return ListJavaFamiliesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListJavaFamilies.ts.html |here} to see how to use ListJavaFamilies API.
     */
    listJavaFamilies(listJavaFamiliesRequest: requests.ListJavaFamiliesRequest): Promise<responses.ListJavaFamiliesResponse>;
    /**
     * Lists the results of a Java migration analysis.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaMigrationAnalysisResultsRequest
     * @return ListJavaMigrationAnalysisResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListJavaMigrationAnalysisResults.ts.html |here} to see how to use ListJavaMigrationAnalysisResults API.
     */
    listJavaMigrationAnalysisResults(listJavaMigrationAnalysisResultsRequest: requests.ListJavaMigrationAnalysisResultsRequest): Promise<responses.ListJavaMigrationAnalysisResultsResponse>;
    /**
     * Returns a list of Java releases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaReleasesRequest
     * @return ListJavaReleasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListJavaReleases.ts.html |here} to see how to use ListJavaReleases API.
     */
    listJavaReleases(listJavaReleasesRequest: requests.ListJavaReleasesRequest): Promise<responses.ListJavaReleasesResponse>;
    /**
     * Lists the JmsPlugins.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJmsPluginsRequest
     * @return ListJmsPluginsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListJmsPlugins.ts.html |here} to see how to use ListJmsPlugins API.
     */
    listJmsPlugins(listJmsPluginsRequest: requests.ListJmsPluginsRequest): Promise<responses.ListJmsPluginsResponse>;
    /**
     * List Java Runtime usage in a specified host filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJreUsageRequest
     * @return ListJreUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListJreUsage.ts.html |here} to see how to use ListJreUsage API.
     */
    listJreUsage(listJreUsageRequest: requests.ListJreUsageRequest): Promise<responses.ListJreUsageResponse>;
    /**
     * List Performance Tuning Analysis results.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPerformanceTuningAnalysisResultsRequest
     * @return ListPerformanceTuningAnalysisResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListPerformanceTuningAnalysisResults.ts.html |here} to see how to use ListPerformanceTuningAnalysisResults API.
     */
    listPerformanceTuningAnalysisResults(listPerformanceTuningAnalysisResultsRequest: requests.ListPerformanceTuningAnalysisResultsRequest): Promise<responses.ListPerformanceTuningAnalysisResultsResponse>;
    /**
     * Returns a list of plugin errors that describe all detected errors.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPluginErrorsRequest
     * @return ListPluginErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListPluginErrors.ts.html |here} to see how to use ListPluginErrors API.
     */
    listPluginErrors(listPluginErrorsRequest: requests.ListPluginErrorsRequest): Promise<responses.ListPluginErrorsResponse>;
    /**
     * Retrieve a paginated list of work items for a specified work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkItemsRequest
     * @return ListWorkItemsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListWorkItems.ts.html |here} to see how to use ListWorkItems API.
     */
    listWorkItems(listWorkItemsRequest: requests.ListWorkItemsRequest): Promise<responses.ListWorkItemsResponse>;
    /**
     * Retrieve a (paginated) list of errors for a specified work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Retrieve a paginated list of logs for a specified work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * List the work requests in a compartment. The query parameter `compartmentId` is required unless the query parameter `id` or `fleetId` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Remove Java installation sites in a Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveFleetInstallationSitesRequest
     * @return RemoveFleetInstallationSitesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/RemoveFleetInstallationSites.ts.html |here} to see how to use RemoveFleetInstallationSites API.
     */
    removeFleetInstallationSites(removeFleetInstallationSitesRequest: requests.RemoveFleetInstallationSitesRequest): Promise<responses.RemoveFleetInstallationSitesResponse>;
    /**
     * Request to perform crypto analysis on one or more selected targets in the Fleet. The result of the crypto analysis will be uploaded to the object storage bucket created by JMS on enabling the Crypto Event Analysis feature in the Fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestCryptoAnalysesRequest
     * @return RequestCryptoAnalysesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/RequestCryptoAnalyses.ts.html |here} to see how to use RequestCryptoAnalyses API.
     */
    requestCryptoAnalyses(requestCryptoAnalysesRequest: requests.RequestCryptoAnalysesRequest): Promise<responses.RequestCryptoAnalysesResponse>;
    /**
     * Request to perform a deployed Java migration analyses. The results of the deployed Java migration analyses will be uploaded to the
     * Object Storage bucket that you designate when you enable the Java Migration Analyses feature.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestDeployedApplicationMigrationAnalysesRequest
     * @return RequestDeployedApplicationMigrationAnalysesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/RequestDeployedApplicationMigrationAnalyses.ts.html |here} to see how to use RequestDeployedApplicationMigrationAnalyses API.
     */
    requestDeployedApplicationMigrationAnalyses(requestDeployedApplicationMigrationAnalysesRequest: requests.RequestDeployedApplicationMigrationAnalysesRequest): Promise<responses.RequestDeployedApplicationMigrationAnalysesResponse>;
    /**
     * Request to perform a Java migration analysis. The results of the Java migration analysis will be uploaded to the
     * Object Storage bucket that you designate when you enable the Java Migration Analysis feature.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestJavaMigrationAnalysesRequest
     * @return RequestJavaMigrationAnalysesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/RequestJavaMigrationAnalyses.ts.html |here} to see how to use RequestJavaMigrationAnalyses API.
     */
    requestJavaMigrationAnalyses(requestJavaMigrationAnalysesRequest: requests.RequestJavaMigrationAnalysesRequest): Promise<responses.RequestJavaMigrationAnalysesResponse>;
    /**
     * Request to collect the JFR recordings on the selected target in the Fleet. The JFR files are uploaded to the object storage bucket created by JMS on enabling Generic JFR feature in the Fleet.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestJfrRecordingsRequest
     * @return RequestJfrRecordingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/RequestJfrRecordings.ts.html |here} to see how to use RequestJfrRecordings API.
     */
    requestJfrRecordings(requestJfrRecordingsRequest: requests.RequestJfrRecordingsRequest): Promise<responses.RequestJfrRecordingsResponse>;
    /**
     * Request to perform performance tuning analyses. The result of performance tuning analysis will be uploaded to the
     * object storage bucket that you designated when you enabled the recording feature.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestPerformanceTuningAnalysesRequest
     * @return RequestPerformanceTuningAnalysesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/RequestPerformanceTuningAnalyses.ts.html |here} to see how to use RequestPerformanceTuningAnalyses API.
     */
    requestPerformanceTuningAnalyses(requestPerformanceTuningAnalysesRequest: requests.RequestPerformanceTuningAnalysesRequest): Promise<responses.RequestPerformanceTuningAnalysesResponse>;
    /**
     * Scan Java Server usage in a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ScanJavaServerUsageRequest
     * @return ScanJavaServerUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ScanJavaServerUsage.ts.html |here} to see how to use ScanJavaServerUsage API.
     */
    scanJavaServerUsage(scanJavaServerUsageRequest: requests.ScanJavaServerUsageRequest): Promise<responses.ScanJavaServerUsageResponse>;
    /**
     * Scan library usage in a fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ScanLibraryUsageRequest
     * @return ScanLibraryUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/ScanLibraryUsage.ts.html |here} to see how to use ScanLibraryUsage API.
     */
    scanLibraryUsage(scanLibraryUsageRequest: requests.ScanLibraryUsageRequest): Promise<responses.ScanLibraryUsageResponse>;
    /**
     * Summarizes the application installation usage in a Fleet filtered by query parameters. In contrast to SummarizeApplicationUsage, which provides only information aggregated by application name, this operation provides installation details. This allows for better focusing of actions.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeApplicationInstallationUsageRequest
     * @return SummarizeApplicationInstallationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeApplicationInstallationUsage.ts.html |here} to see how to use SummarizeApplicationInstallationUsage API.
     */
    summarizeApplicationInstallationUsage(summarizeApplicationInstallationUsageRequest: requests.SummarizeApplicationInstallationUsageRequest): Promise<responses.SummarizeApplicationInstallationUsageResponse>;
    /**
     * List application usage in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeApplicationUsageRequest
     * @return SummarizeApplicationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeApplicationUsage.ts.html |here} to see how to use SummarizeApplicationUsage API.
     */
    summarizeApplicationUsage(summarizeApplicationUsageRequest: requests.SummarizeApplicationUsageRequest): Promise<responses.SummarizeApplicationUsageResponse>;
    /**
     * Summarize installation usage of an application deployed on Java servers in a fleet filtered by query parameters. In contrast to SummarizeDeployedApplicationUsage, which provides only information aggregated by the deployment information, this operation provides installation details and allows for better focusing of actions.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDeployedApplicationInstallationUsageRequest
     * @return SummarizeDeployedApplicationInstallationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeDeployedApplicationInstallationUsage.ts.html |here} to see how to use SummarizeDeployedApplicationInstallationUsage API.
     */
    summarizeDeployedApplicationInstallationUsage(summarizeDeployedApplicationInstallationUsageRequest: requests.SummarizeDeployedApplicationInstallationUsageRequest): Promise<responses.SummarizeDeployedApplicationInstallationUsageResponse>;
    /**
     * List of deployed applications in a Fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDeployedApplicationUsageRequest
     * @return SummarizeDeployedApplicationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeDeployedApplicationUsage.ts.html |here} to see how to use SummarizeDeployedApplicationUsage API.
     */
    summarizeDeployedApplicationUsage(summarizeDeployedApplicationUsageRequest: requests.SummarizeDeployedApplicationUsageRequest): Promise<responses.SummarizeDeployedApplicationUsageResponse>;
    /**
     * Returns a high level summary of FleetErrors.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeFleetErrorsRequest
     * @return SummarizeFleetErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeFleetErrors.ts.html |here} to see how to use SummarizeFleetErrors API.
     */
    summarizeFleetErrors(summarizeFleetErrorsRequest: requests.SummarizeFleetErrorsRequest): Promise<responses.SummarizeFleetErrorsResponse>;
    /**
     * List Java installation usage in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeInstallationUsageRequest
     * @return SummarizeInstallationUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeInstallationUsage.ts.html |here} to see how to use SummarizeInstallationUsage API.
     */
    summarizeInstallationUsage(summarizeInstallationUsageRequest: requests.SummarizeInstallationUsageRequest): Promise<responses.SummarizeInstallationUsageResponse>;
    /**
     * List Java Server instances in a fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeJavaServerInstanceUsageRequest
     * @return SummarizeJavaServerInstanceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeJavaServerInstanceUsage.ts.html |here} to see how to use SummarizeJavaServerInstanceUsage API.
     */
    summarizeJavaServerInstanceUsage(summarizeJavaServerInstanceUsageRequest: requests.SummarizeJavaServerInstanceUsageRequest): Promise<responses.SummarizeJavaServerInstanceUsageResponse>;
    /**
     * List of Java servers in a Fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeJavaServerUsageRequest
     * @return SummarizeJavaServerUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeJavaServerUsage.ts.html |here} to see how to use SummarizeJavaServerUsage API.
     */
    summarizeJavaServerUsage(summarizeJavaServerUsageRequest: requests.SummarizeJavaServerUsageRequest): Promise<responses.SummarizeJavaServerUsageResponse>;
    /**
     * List Java Runtime usage in a specified Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeJreUsageRequest
     * @return SummarizeJreUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeJreUsage.ts.html |here} to see how to use SummarizeJreUsage API.
     */
    summarizeJreUsage(summarizeJreUsageRequest: requests.SummarizeJreUsageRequest): Promise<responses.SummarizeJreUsageResponse>;
    /**
     * List libraries in a fleet filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeLibraryUsageRequest
     * @return SummarizeLibraryUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeLibraryUsage.ts.html |here} to see how to use SummarizeLibraryUsage API.
     */
    summarizeLibraryUsage(summarizeLibraryUsageRequest: requests.SummarizeLibraryUsageRequest): Promise<responses.SummarizeLibraryUsageResponse>;
    /**
     * List managed instance usage in a Fleet filtered by query parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeManagedInstanceUsageRequest
     * @return SummarizeManagedInstanceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeManagedInstanceUsage.ts.html |here} to see how to use SummarizeManagedInstanceUsage API.
     */
    summarizeManagedInstanceUsage(summarizeManagedInstanceUsageRequest: requests.SummarizeManagedInstanceUsageRequest): Promise<responses.SummarizeManagedInstanceUsageResponse>;
    /**
     * Returns a high level summary of PluginErrors.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizePluginErrorsRequest
     * @return SummarizePluginErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizePluginErrors.ts.html |here} to see how to use SummarizePluginErrors API.
     */
    summarizePluginErrors(summarizePluginErrorsRequest: requests.SummarizePluginErrorsRequest): Promise<responses.SummarizePluginErrorsResponse>;
    /**
     * Retrieve the inventory of JMS resources in the specified compartment: a list of the number of _active_ fleets, managed instances, Java Runtimes, Java installations, and applications.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeResourceInventoryRequest
     * @return SummarizeResourceInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/SummarizeResourceInventory.ts.html |here} to see how to use SummarizeResourceInventory API.
     */
    summarizeResourceInventory(summarizeResourceInventoryRequest: requests.SummarizeResourceInventoryRequest): Promise<responses.SummarizeResourceInventoryResponse>;
    /**
     * Request to perform validation of the DRS file and update the existing file in the Object Storage.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDrsFileRequest
     * @return UpdateDrsFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/UpdateDrsFile.ts.html |here} to see how to use UpdateDrsFile API.
     */
    updateDrsFile(updateDrsFileRequest: requests.UpdateDrsFileRequest): Promise<responses.UpdateDrsFileResponse>;
    /**
     * Updates existing export setting for the specified fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateExportSettingRequest
     * @return UpdateExportSettingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/UpdateExportSetting.ts.html |here} to see how to use UpdateExportSetting API.
     */
    updateExportSetting(updateExportSettingRequest: requests.UpdateExportSettingRequest): Promise<responses.UpdateExportSettingResponse>;
    /**
     * Update the Fleet specified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetRequest
     * @return UpdateFleetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/UpdateFleet.ts.html |here} to see how to use UpdateFleet API.
     */
    updateFleet(updateFleetRequest: requests.UpdateFleetRequest): Promise<responses.UpdateFleetResponse>;
    /**
     * Update advanced feature configurations for the Fleet.
     * Ensure that the namespace and bucket storage are created prior to turning on the JfrRecording or CryptoEventAnalysis feature.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetAdvancedFeatureConfigurationRequest
     * @return UpdateFleetAdvancedFeatureConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/UpdateFleetAdvancedFeatureConfiguration.ts.html |here} to see how to use UpdateFleetAdvancedFeatureConfiguration API.
     */
    updateFleetAdvancedFeatureConfiguration(updateFleetAdvancedFeatureConfigurationRequest: requests.UpdateFleetAdvancedFeatureConfigurationRequest): Promise<responses.UpdateFleetAdvancedFeatureConfigurationResponse>;
    /**
     * Update the Fleet Agent Configuration for the specified Fleet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFleetAgentConfigurationRequest
     * @return UpdateFleetAgentConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/UpdateFleetAgentConfiguration.ts.html |here} to see how to use UpdateFleetAgentConfiguration API.
     */
    updateFleetAgentConfiguration(updateFleetAgentConfigurationRequest: requests.UpdateFleetAgentConfigurationRequest): Promise<responses.UpdateFleetAgentConfigurationResponse>;
    /**
     * Updates the Fleet of a JmsPlugin.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJmsPluginRequest
     * @return UpdateJmsPluginResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.oracle.com/en-us/iaas/tools/typescript-sdk-examples/latest/jms/UpdateJmsPlugin.ts.html |here} to see how to use UpdateJmsPlugin API.
     */
    updateJmsPlugin(updateJmsPluginRequest: requests.UpdateJmsPluginRequest): Promise<responses.UpdateJmsPluginResponse>;
}
export {};
